@@ -1,4 +1,5 @@
 <?php
+
 /**
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  *
@@ -23,8 +24,9 @@
 
 namespace OCA\Activity\BackgroundJob;
 
-use OC\BackgroundJob\TimedJob;
 use OCA\Activity\MailQueueHandler;
+use OCP\AppFramework\Utility\ITimeFactory;
+use OCP\BackgroundJob\TimedJob;
 
 /**
  * Class EmailNotification
@@ -33,23 +35,15 @@ use OCA\Activity\MailQueueHandler;
  */
 class EmailNotification extends TimedJob {
 
-	/** @var MailQueueHandler */
-	protected $queueHandler;
+	public function __construct(
+		ITimeFactory $time,
+		protected MailQueueHandler $queueHandler,
+		protected bool $isCLI,
+	) {
+		parent::__construct($time);
 
-	/** @var bool */
-	protected $isCLI;
-
-	/**
-	 * @param MailQueueHandler $mailQueueHandler
-	 * @param bool $isCLI
-	 */
-	public function __construct(MailQueueHandler $mailQueueHandler,
-								$isCLI) {
-		// Run all 15 Minutes
-		$this->setInterval(15 * 60);
-
-		$this->queueHandler = $mailQueueHandler;
-		$this->isCLI = $isCLI;
+		// Run everytime cron is executed, so the batching doesn't delay too much
+		$this->setInterval(1);
 	}
 
 	protected function run($argument) {
