@@ -72,6 +72,78 @@ OC.L10N.register(
     "Description: %s" : "Popis: %s",
     "Where: %s" : "Kde: %s",
     "%1$s via %2$s" : "%1$s cez %2$s",
+    "In the past on %1$s for the entire day" : "V minulosti %1$s na celý deň",
+    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Za %n minútu %1$s na celý deň","Za %n minúty %1$s na celý deň","Za %n minúť %1$s na celý deň","Za %n minúť %1$s na celý deň"],
+    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Za %n hodinu %1$s na celý deň","Za %n hodiny %1$s na celý deň","Za %n hodín %1$s na celý deň","Za %n hodín %1$s na celý deň"],
+    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Za %n deň %1$s na celý deň","Za %n dni %1$s na celý deň","Za %n dní %1$s na celý deň","Za %n dní %1$s na celý deň"],
+    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Za %n týždeň %1$s na celý deň","Za %n týždne %1$s na celý deň","Za %n týždňov %1$s na celý deň","Za %n týždňov %1$s na celý deň"],
+    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Za %n mesiac %1$s na celý deň","Za %n mesiace %1$s na celý deň","Za %n mesiacov %1$s na celý deň","Za %n mesiacov %1$s na celý deň"],
+    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Za %n rok %1$s na celý deň","Za %n roky %1$s na celý deň","Za %n rokov %1$s na celý deň","Za %n rokov %1$s na celý deň"],
+    "In the past on %1$s between %2$s - %3$s" : "V minulosti %1$s medzi %2$s - %3$s",
+    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Za %n minútu %1$s %2$s medzi %2$s - %3$s","Za %n minúty %1$s %2$s medzi %2$s - %3$s","Za %n minút %1$s %2$s medzi %2$s - %3$s","Za %n minút %1$s %2$s medzi %2$s - %3$s"],
+    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Za %n hodinu %1$s %2$s medzi %2$s - %3$s","Za %n hodiny %1$s %2$s medzi %2$s - %3$s","Za %n hodín %1$s %2$s medzi %2$s - %3$s","Za %n hodín %1$s %2$s medzi %2$s - %3$s"],
+    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Za %n deň %1$s %2$s medzi %2$s - %3$s","Za %n dni %1$s %2$s medzi %2$s - %3$s","Za %n dní %1$s %2$s medzi %2$s - %3$s","Za %n dní %1$s %2$s medzi %2$s - %3$s"],
+    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["Za %n týždeň %1$s %2$s medzi %2$s - %3$s","Za %n týždne %1$s %2$s medzi %2$s - %3$s","Za %n týždňov %1$s %2$s medzi %2$s - %3$s","Za %n týždňov %1$s %2$s medzi %2$s - %3$s"],
+    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Za %n mesiac %1$s %2$s medzi %2$s - %3$s","Za %n mesiace %1$s %2$s medzi %2$s - %3$s","Za %n mesiacov %1$s %2$s medzi %2$s - %3$s","Za %n mesiacov %1$s %2$s medzi %2$s - %3$s"],
+    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["Za %n rok %1$s %2$s medzi %2$s - %3$s","Za %n roky %1$s %2$s medzi %2$s - %3$s","Za %n rokov %1$s %2$s medzi %2$s - %3$s","Za %n rokov %1$s %2$s medzi %2$s - %3$s"],
+    "Could not generate when statement" : "Nepodarilo sa vygenerovať vyhlásenie kedy",
+    "Every Day for the entire day" : "Každý deň, na celý deň",
+    "Every Day for the entire day until %1$s" : "Každý deň, na celý deň, do %1$s",
+    "Every Day between %1$s - %2$s" : "Každý deň medzi %1$s - %2$s",
+    "Every Day between %1$s - %2$s until %3$s" : "Každý deň medzi %1$s - %2$s do %3$s",
+    "Every %1$d Days for the entire day" : "Každých %1$d dní, na celý deň",
+    "Every %1$d Days for the entire day until %2$s" : "Každých %1$d dní, na celý deň, do %2$s",
+    "Every %1$d Days between %2$s - %3$s" : "Každých %1$d dní, medzi %2$s - %3$s",
+    "Every %1$d Days between %2$s - %3$s until %4$s" : "Každých %1$d dní, medzi %2$s - %3$s do %4$s",
+    "Could not generate event recurrence statement" : "Nepodarilo sa vygenerovať vyhlásenie o opakovaní udalosti",
+    "Every Week on %1$s for the entire day" : "Každý týždeň %1$s na celý deň",
+    "Every Week on %1$s for the entire day until %2$s" : "Každý týždeň %1$s na celý deň do %2$s",
+    "Every Week on %1$s between %2$s - %3$s" : "Každý týždeň %1$s medzi %2$s - %3$s",
+    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Každý týždeň %1$s medzi %2$s - %3$s do %4$s",
+    "Every %1$d Weeks on %2$s for the entire day" : "Každých %1$d týždňov %2$s, na celý deň",
+    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Každých %1$d týždňov od %2$s na celý deň do %3$s",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Každých %1$d týždňov od %2$s na celý deň medzi %3$s - %4$s",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Každých %1$d týždňov od %2$s na celý deň medzi %3$s - %4$s do %5$s",
+    "Every Month on the %1$s for the entire day" : "Každý mesiac od %1$s na celý deň",
+    "Every Month on the %1$s for the entire day until %2$s" : "Každý mesiac od %1$s na celý deň do %2$s",
+    "Every Month on the %1$s between %2$s - %3$s" : "Každý mesiac od %1$s medzi %2$s - %3$s",
+    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Každý mesiac od %1$s medzi %2$s - %3$s do %4$s",
+    "Every %1$d Months on the %2$s for the entire day" : "Každých %1$d mesiacov od %2$s na celý deň",
+    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Každých %1$d mesiacov od %2$s na celý deň do %3$s",
+    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Každých %1$d mesiacov od %2$s medzi %3$s - %4$s",
+    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Každých %1$d mesiacov od %2$s medzi %3$s - %4$s do %5$s",
+    "Every Year in %1$s on the %2$s for the entire day" : "Každý rok v %1$s od %2$s na celý deň",
+    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Každý rok v %1$s od %2$s na celý deň do %3$s",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Každý rok v %1$s od %2$s medzi %3$s - %4$s",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Každý rok v %1$s od %2$s medzi %3$s - %4$s do %5$s",
+    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Každé %1$d roky v %2$s od %3$s na celý deň",
+    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Každé %1$d roky v %2$s od %3$s na celý deň do %4$s",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Každé %1$d roky v %2$s od %3$s medzi %4$s - %5$s",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Každé %1$d roky v %2$s od %3$s medzi %4$s - %5$s do %6$s",
+    "On specific dates for the entire day until %1$s" : "V konkrétnych dátumoch na celý deň %1$s",
+    "On specific dates between %1$s - %2$s until %3$s" : "V konkrétnych dátumoch medzi %1$s - %2$s do %3$s",
+    "In the past on %1$s" : "V minulosti %1$s",
+    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["O minútu %1$s","Za %n minúty %1$s","Za %n minút %1$s","Za %n minút %1$s"],
+    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["Za hodinu %1$s","Za %n hodiny %1$s","Za %n hodín %1$s","Za %n hodín %1$s"],
+    "_In a day on %1$s_::_In %n days on %1$s_" : ["Za deň %1$s","Za %n dni %1$s","Za %n dní %1$s","Za %n dní %1$s"],
+    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["Za týždeň %1$s","Za %n týždne %1$s","Za %n týždňov %1$s","Za %n týždňov %1$s"],
+    "_In a month on %1$s_::_In %n months on %1$s_" : ["Za mesiac %1$s","Za %n mesiace %1$s","Za %n mesiacov %1$s","Za %n mesiacov %1$s"],
+    "_In a year on %1$s_::_In %n years on %1$s_" : ["Za rok %1$s","Za %n roky %1$s","Za %n rokov %1$s","Za %n rokov %1$s"],
+    "In the past on %1$s then on %2$s" : "V minulosti %1$s a potom %2$s",
+    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Za minútu %1$s a potom %2$s","Za %n minúty %1$s a potom %2$s","Za %n minút %1$s a potom %2$s","Za %n minút %1$s a potom %2$s"],
+    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Za hodinu %1$s a potom %2$s","Za %n hodiny %1$s a potom %2$s","Za %n hodín %1$s a potom %2$s","Za %n hodín %1$s a potom %2$s"],
+    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Za deň %1$s a potom %2$s","Za %n dni %1$s a potom %2$s","Za %n dní %1$s a potom %2$s","Za %n dní %1$s a potom %2$s"],
+    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["Za týždeň %1$s a potom %2$s","Za %n týždne %1$s a potom %2$s","Za %n týždňov %1$s a potom %2$s","Za %n týždňov %1$s a potom %2$s"],
+    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Za mesiac %1$s a potom %2$s","Za %n mesiace %1$s a potom %2$s","Za %n mesiacov %1$s a potom %2$s","Za %n mesiacov %1$s a potom %2$s"],
+    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["Za rok %1$s a potom %2$s","Za %n roky %1$s a potom %2$s","Za %n rokov %1$s a potom %2$s","Za %n rokov %1$s a potom %2$s"],
+    "In the past on %1$s then on %2$s and %3$s" : "V minulosti %1$s potom %2$s a %3$s",
+    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Za minútu %1$s potom %2$s a %3$s","Za %n minúty %1$s potom %2$s a %3$s","Za %n minút %1$s potom %2$s a %3$s","Za %n minút %1$s potom %2$s a %3$s"],
+    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Za  hodinu %1$s potom %2$s a %3$s","Za %n hodiny %1$s potom %2$s a %3$s","Za %n hodín %1$s potom %2$s a %3$s","Za %n hodín %1$s potom %2$s a %3$s"],
+    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Za deň %1$s potom %2$s a %3$s","Za %n dni %1$s potom %2$s a %3$s","Za %n dní %1$s potom %2$s a %3$s","Za %n dní %1$s potom %2$s a %3$s"],
+    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["Za týždeň %1$s potom %2$s a %3$s","Za %n týždne %1$s potom %2$s a %3$s","Za %n týždňov %1$s potom %2$s a %3$s","Za %n týždňov %1$s potom %2$s a %3$s"],
+    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Za mesiac %1$s potom %2$s a %3$s","Za %n mesiace %1$s potom %2$s a %3$s","Za %n mesiacov %1$s potom %2$s a %3$s","Za %n mesiacov %1$s potom %2$s a %3$s"],
+    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Za rok %1$s potom %2$s a %3$s","Za %n roky %1$s potom %2$s a %3$s","Za %n rokov %1$s potom %2$s a %3$s","Za %n rokov %1$s potom %2$s a %3$s"],
+    "Could not generate next recurrence statement" : "Nepodarilo sa vygenerovať ďalšie opakovanie",
     "Cancelled: %1$s" : "Zrušené: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" bolo zrušené",
     "Re: %1$s" : "Re: %1$s",
@@ -89,6 +161,7 @@ OC.L10N.register(
     "When:" : "Kedy:",
     "Location:" : "Miesto:",
     "Link:" : "Odkaz:",
+    "Occurring:" : "Výskyt:",
     "Accept" : "Schváliť",
     "Decline" : "Odmietnuť",
     "More options …" : "Ďalšie nastavenia ...",
@@ -113,7 +186,15 @@ OC.L10N.register(
     "November" : "November",
     "December" : "December",
     "First" : "Prvé",
+    "Second" : "Druhý",
+    "Third" : "Tretí",
+    "Fourth" : "Štvrtý",
+    "Fifth" : "Piate",
     "Last" : "Posledné",
+    "Second Last" : "Predposledný",
+    "Third Last" : "Tretí odzadu",
+    "Fourth Last" : "Štvrtý odzadu",
+    "Fifth Last" : "Piatu odzadu",
     "Contacts" : "Kontakty",
     "{actor} created address book {addressbook}" : "{actor} vytvoril adresár {addressbook}",
     "You created address book {addressbook}" : "Vytvorili ste adresár {addressbook}",
@@ -142,6 +223,7 @@ OC.L10N.register(
     "Accounts" : "Účty",
     "System address book which holds all accounts" : "Systémový adresár, ktorý obsahuje všetky účty.",
     "File is not updatable: %1$s" : "Súbor nie je možné aktualizovať: %1$s",
+    "Failed to get storage for file" : "Nepodarilo sa získať miesto pre súbor",
     "Could not write to final file, canceled by hook" : "Nepodarilo sa zapísať do konečného súboru, zrušené háčikom (hook)",
     "Could not write file contents" : "Nepodarilo sa zapísať obsah súboru",
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtov","%n bajtov"],
@@ -150,12 +232,14 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "Nepodarilo sa premenovať dočasný súbor na finálny, zrušené háčikom (hook)",
     "Could not rename part file to final file" : "Nepodarilo sa premenovať dočasný súbor na finálny.",
     "Failed to check file size: %1$s" : "Kontrola veľkosti súboru zlyhala: %1$s",
-    "Could not open file" : "Súbor sa nepodarilo otvoriť",
+    "Could not open file: %1$s, file does seem to exist" : "Nie je možné otvoriť súbor: %1$s, vyzerá to že súbor neexistuje",
+    "Could not open file: %1$s, file doesn't seem to exist" : "Nie je možné otvoriť súbor: %1$s, vyzerá to že súbor neexistuje",
     "Encryption not ready: %1$s" : "Šifrovanie nie je dostupné: %1$s",
     "Failed to open file: %1$s" : "Otvorenie súboru zlyhalo: %1$s",
     "Failed to unlink: %1$s" : "Odpojenie zlyhalo: %1$s",
     "Failed to write file contents: %1$s" : "Zapisovanie obsahu súboru zlyhalo: %1$s",
     "File not found: %1$s" : "Súbor nebol nájdený: %1$s",
+    "Invalid target path" : "Neplatná cesta cieľa",
     "System is in maintenance mode." : "Systém je v režime údržby.",
     "Upgrade needed" : "Je potrebná aktualizácia",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ak chcete používať CalDAV alebo CardDAV v iOS alebo macOS, musí byť %s nakonfigurovaný na používanie HTTPS.",
@@ -166,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "Dokončené %s",
     "Due on %s by %s" : "Termín od %s do %s",
     "Due on %s" : "Termín do %s",
+    "System Address Book" : "Systémový Adresár",
+    "The system address book contains contact information for all users in your instance." : "Systémový adresár obsahuje kontaktné informácie o všetkých užívateľov vo vašej inštancii.",
+    "Enable System Address Book" : "Povoliť systémový Adresár",
     "DAV system address book" : "Systémový DAV adresár",
     "No outstanding DAV system address book sync." : "Žiadna zostávajúca synchronizácia adresára systému DAV.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV synchronizácia systémového adresára ešte nebola spustená, pretože vaša inštancia má viac ako 1000 užívateľov alebo sa vyskytla chyba. Prosím, spustite ju manuálne volaním \"occ dav:sync-system-addressbook\".",
@@ -177,16 +264,23 @@ OC.L10N.register(
     "Calendars including events, details and attendees" : "Kalendáre vrátane udalostí, podrobností a účastníkov",
     "Contacts and groups" : "Kontakty a skupiny",
     "WebDAV" : "WebDAV",
-    "First day" : "Prvý deň",
-    "Last day (inclusive)" : "Posledný deň (vrátane)",
-    "Short absence status" : "Status pre Krátku neprítomnosť",
-    "Long absence Message" : "Sprava pri Dlhej neprítomnosti",
-    "Save" : "Uložiť",
-    "Disable absence" : "Zakázať neprítomnosť",
     "Absence saved" : "Neprítomnosť uložená",
     "Failed to save your absence settings" : "Nepodarilo sa uložiť vaše nastavenia neprítomnosti.",
     "Absence cleared" : "Neprítomnosť odstránená",
     "Failed to clear your absence settings" : "Nepodarilo sa vymazať vaše nastavenia neprítomnosti.",
+    "First day" : "Prvý deň",
+    "Last day (inclusive)" : "Posledný deň (vrátane)",
+    "Out of office replacement (optional)" : "Zástup keď je mimo kancelárie (voliteľné)",
+    "Name of the replacement" : "Názov náhrady",
+    "No results." : "Žiadne výsledky.",
+    "Start typing." : "Začnite písať.",
+    "Short absence status" : "Status pre Krátku neprítomnosť",
+    "Long absence Message" : "Správa pri Dlhej neprítomnosti",
+    "Save" : "Uložiť",
+    "Disable absence" : "Zakázať neprítomnosť",
+    "Failed to load availability" : "Nepodarilo sa načítať dostupnosť",
+    "Saved availability" : "Dostupnosť bola uložená",
+    "Failed to save availability" : "Nepodarilo sa uložiť dostupnosť",
     "Time zone:" : "Časová zóna:",
     "to" : "do",
     "Delete slot" : "Odstrániť slot",
@@ -196,13 +290,12 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "Vyberte začiatočný čas pre {dayName}",
     "Pick a end time for {dayName}" : "Vyberte koncový čas pre {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Automaticky nastaviť stav používateľa na „Nerušiť“ ak nie ste dostupný,  pre stlmenie všetkých upozornení.",
-    "Failed to load availability" : "Nepodarilo sa načítať dostupnosť",
-    "Saved availability" : "Dostupnosť bola uložená",
-    "Failed to save availability" : "Nepodarilo sa uložiť dostupnosť",
     "Availability" : "Dostupnosť",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Ak nakonfigurujete svoj pracovný čas, ostatní užívatelia vás uvidia ako neprítomného, keď si rezervujete schôdzku",
     "Absence" : "Neprítomnosť",
     "Configure your next absence period." : "Nastavte si ďalšie obdobie svojej neprítomnosti.",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Tiež nainštalujte {calendarappstoreopen}apku Kalendár{linkclose} alebo {calendardocopen}pripojte svoj počítač a smartfón pre synchronizáciu ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Uistite sa, že ste správne nastavili {emailopen}e-mailový server{linkclose}.",
     "Calendar server" : "Kalendárový server",
     "Send invitations to attendees" : "Odoslanie pozvánok účastníkom",
     "Automatically generate a birthday calendar" : "Automaticky generovať narodeninový kalendár",
@@ -213,17 +306,17 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Posielať upozornenia na pripomienky aj zdieľaným osobám v kalendári",
     "Reminders are always sent to organizers and attendees." : "Upozornenia sa vždy posielajú organizátorom a účastníkom.",
     "Enable notifications for events via push" : "Zapnúť oznámenia o udalostiach prostredníctvom technológie push.",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Tiež nainštalujte {calendarappstoreopen}apku Kalendár{linkclose} alebo {calendardocopen}pripojte svoj počítač a smartfón pre synchronizáciu ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Uistite sa, že ste správne nastavili {emailopen}e-mailový server{linkclose}.",
+    "Cancel" : "Zrušiť",
+    "Import" : "Import",
+    "Error while saving settings" : "Chyba pri ukladaní nastavení",
     "There was an error updating your attendance status." : "Nastal problém pri aktualizácii Vašej účasti.",
     "Please contact the organizer directly." : "Prosím kontaktujte priamo organizátora.",
     "Are you accepting the invitation?" : "Príjmate pozvánku?",
     "Tentative" : "Neistý",
     "Your attendance was updated successfully." : "Vaša účasť bola aktualizovaná úspešne.",
-    "To-dos" : "Úlohy",
     "Time:" : "Čas:",
+    "Could not open file" : "Súbor sa nepodarilo otvoriť",
     "Invalid chunk name" : "Neplatný názov bloku",
-    "Could not rename part file assembled from chunks" : "Nepodarilo sa premenovať dočasný súbor vytvorený z blokov",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Ak nakonfigurujete svoj pracovný čas, ostatní používatelia uvidia, keď si rezervujete schôdzku, keď nebudete v práci."
+    "Could not rename part file assembled from chunks" : "Nepodarilo sa premenovať dočasný súbor vytvorený z blokov"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
