@@ -31,18 +31,8 @@ OC.L10N.register(
     "What's new?" : "Kas naujo?",
     "Read more" : "Daugiau skaitykite",
     "Share on social media" : "Bendrinti socialiniuose tinkluose",
-    "Copied!" : "Nukopijuota!",
-    "Not supported!" : "Nepalaikoma!",
-    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
-    "Press Ctrl-C to copy." : "Paspauskite Vald-C, norėdami nukopijuoti.",
     "App recommendation: Nextcloud Calendar" : "Programėlės rekomendacija: Nextcloud kalendorius",
     "App recommendation: Nextcloud Contacts" : "Programėlės rekomendacija: Nextcloud adresatai",
-    "App recommendation: Nextcloud Mail" : "Programėlės rekomendacija: Nextcloud paštas",
-    "About" : "Apie",
-    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s suteikia jums prieigą prie jūsų failų visur, kur bebūtumėte. Mūsų lengvi naudoti darbalaukio ir mobilieji klientai yra prieinami pagrindinėms platformoms visiškai nemokamai.",
-    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Nusistatykite sinchronizavimo kliento programas naudodami <a href=\"%s\">programėlės slaptažodį</a>. Tokiu būdu užtikrinsite, jog galėsite panaikinti prieigą tuo atveju, jei pamesite įrenginį.",
-    "Connect other apps to %s" : "Prijunkite kitas programas prie %s",
-    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Be mobiliųjų programėlių ir darbalaukio kliento programos taip pat galite prijungti bet kokią kitą programinę įrangą, palaikančią WebDAV/CalDAV/CardDAV protokolus į %s.",
-    "Copy link" : "Kopijuoti nuorodą"
+    "App recommendation: Nextcloud Mail" : "Programėlės rekomendacija: Nextcloud paštas"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
