@@ -1,8 +1,6 @@
 OC.L10N.register(
     "text",
     {
-    "New text file" : "新文字檔",
-    "Create new text file" : "建立新文字檔案",
     "The file was uploaded" : "檔案已上傳",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
@@ -14,29 +12,32 @@ OC.L10N.register(
     "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案超過上限 %s",
     "Nextcloud Text" : "Nextcloud 文字編輯器",
     "text document" : "文字文件",
+    "New text file" : "新文字檔",
+    "Create new text file" : "建立新文字檔案",
     "Editing session has expired. Please reload the page." : "編輯工作階段已過期。請重新載入頁面。",
     "{user} has mentioned you in the text document {node}" : "{user} 在文字文件 {node} 中提到您",
     "This file cannot be displayed as download is disabled by the share" : "此檔案無法顯示，因為分享時已停用下載",
-    "No permission to access this file." : "無權存取此檔案。",
+    "File not found" : "找不到檔案",
     "Readme" : "說明",
     "Text" : "文字編輯器",
     "📝 Collaborative document editing" : "📝 協作文件編輯",
     "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 協作文件編輯！**\n\n- **📝 聚焦編輯：** 沒有不重要的東西，只有你需要的格式化。\n- **🙋 共同作業：** 與朋友及同事協作，無關他們是否使用 Nextcloud！\n- **💾 開放格式：** 檔案會以 [Markdown](https://en.wikipedia.org/wiki/Markdown) 儲存，所以你也能在其他文字編輯器編輯。\n- **✊ 強大基礎：** 我們使用基於 [🦉 ProseMirror](https://prosemirror.net) 的 [🐈 tiptap](https://tiptap.scrumpy.io) – 超級感謝他們！",
+    "Insert result" : "插入結果",
+    "Nextcloud Assistant result copied" : "已複製 Nextcloud 小幫手結果",
+    "Could not copy result to clipboard" : "無法複製結果至剪貼簿",
     "Nextcloud Assistant" : "Nextcloud 小幫手",
     "Translate" : "翻譯",
     "Show assistant results" : "顯示小幫手結果",
-    "Insert result" : "插入結果",
+    "Assistant results" : "小幫手結果",
     "Show result" : "顯示結果",
     "Delete task" : "刪除工作項目",
-    "Nextcloud Assistant result copied" : "已複製 Nextcloud 小幫手結果",
-    "Could not copy result to clipboard" : "無法複製結果至剪貼簿",
-    "Use current version" : "使用目前版本",
-    "Use the saved version" : "使用儲存版本",
+    "Overwrite the file and save the current changes" : "覆寫檔案並儲存目前變更",
+    "Discard the current changes and load the latest version" : "放棄目前變更並載入最新版本",
     "Reload" : "重新載入",
-    "Document has been changed outside of the editor. The changes cannot be applied" : "文件已在編輯器外變更。無法套用變更。",
-    "Document could not be loaded. Please check your internet connection." : "無法載入文件。請檢查您的網路連線。",
+    "The file was overwritten. Your current changes cannot be auto-saved. Please choose how to proceed." : "檔案已被覆寫。無法自動儲存您目前的變更。請選擇要如何繼續。",
+    "The document could not be loaded. Please check your internet connection." : "無法載入文件。請檢查您的網際網路連線。",
     "Reconnect" : "重新連接",
-    "Document idle for {timeout} minutes, click to continue editing" : "文件已閒置 {timeout} 分鐘。點選以繼續編輯",
+    "You've been disconnected from the server." : "您已與伺服器斷線。",
     "This file is opened read-only as it is currently locked by {user}." : "此檔案以唯讀模式開啟，因為其目前被 {user} 鎖定。",
     "Close outline view" : "關閉大綱檢視",
     "Outline" : "大綱",
@@ -44,17 +45,20 @@ OC.L10N.register(
     "Edit guest name" : "編輯訪客名稱",
     "Guest" : "訪客",
     "Save guest name" : "儲存訪客名稱",
+    "Uploading multiple attachments failed." : "上傳多個附件失敗。",
+    "Uploading attachment failed: {error}" : "上傳附件失敗：{error}",
+    "Uploading attachment failed." : "上傳附件失敗。",
     "Insert an attachment" : "插入附件",
+    "Failed to insert from Files" : "從檔案插入失敗",
     "Preview options" : "預覽選項",
     "Text only" : "僅文字",
     "Show link preview" : "顯示連結預覽",
+    "Open in new tab" : "以新分頁開啟",
     "Remove link" : "移除連結",
-    "guest" : "訪客",
-    "Show author colors" : "顯示作者顏色",
-    "Author colors are only shown until everyone has closed the document." : "僅在所有人都關閉文件前才顯示文件顏色。",
     "Active people" : "活躍的人",
-    "Save document" : "儲存文件",
-    "Last saved" : "最後儲存於",
+    "guest" : "訪客",
+    "Full width editor" : "完整寬度編輯器",
+    "Open the Smart Picker" : "開啟智慧型挑選器",
     "Offline" : "離線",
     "Offline, changes will be saved when online" : "離線，將會在連線時儲存變更",
     "Saving …" : "正在儲存……",
@@ -62,8 +66,10 @@ OC.L10N.register(
     "Last saved {lastSave}" : "上次儲存於 {lastSave}",
     "The document has been changed outside of the editor. The changes cannot be applied." : "文件已在編輯器外變更。變更無法套用。",
     "Unsaved changes" : "未儲存變更",
+    "Save document" : "儲存文件",
+    "Last saved" : "最後儲存於",
     "Connection failed." : "連線失敗。",
-    "Formatting help" : "格式化說明",
+    "Formatting and shortcuts" : "格式化與捷徑",
     "Speed up your writing with simple shortcuts." : "使用簡單的快捷鍵加速您的寫作。",
     "Just type the Markdown syntax or use keyboard shortcuts from below." : "僅需輸入 Markdown 語法或使用下方的鍵盤快捷鍵即可。",
     "Just type the Markdown syntax from below." : "僅需輸入下方的 Markdown 語法即可。",
@@ -78,7 +84,6 @@ OC.L10N.register(
     "Shift" : "Shift",
     "Bold" : "粗體",
     "Bold text" : "粗體文字",
-    "Ctrl" : "Ctrl",
     "Italic" : "斜體",
     "Italicized text" : "義式斜體文字",
     "Strikethrough" : "刪除線",
@@ -99,41 +104,54 @@ OC.L10N.register(
     "Quoted text" : "引用文字",
     "Code block" : "程式碼區塊",
     "Some code" : "一些程式碼",
+    "Link" : "連結",
+    "Insert emoji" : "插入表情符號",
+    "emoji" : "表情符號",
+    "Mention someone" : "提及某人",
+    "name" : "名稱",
+    "Smart picker" : "智慧型挑選器",
+    "something" : "一些東西",
+    "Action" : "動作",
+    "Undo" : "復原",
+    "Redo" : "重作",
+    "Toggle outline" : "切換輪廓",
+    "Alt" : "Alt",
+    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
+    "Copy link to clipboard" : "複製連結到剪貼簿",
     "Edit link" : "編輯連結",
     "Save changes" : "保存變更",
     "Cancel" : "取消",
     "URL" : "URL",
-    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
-    "Copy link to clipboard" : "複製連結到剪貼簿",
     "Upload from computer" : "從電腦上傳",
     "Insert from Files" : "從檔案插入",
+    "Formatting help" : "格式化說明",
     "Link to file or folder" : "連結至檔案或資料夾",
     "Link to website" : "連結至網站",
     "Update link" : "更新連結",
-    "Open the Smart Picker" : "開啟智慧型挑選器",
-    "Select file or folder to link to" : "選取要連結的檔案或資料夾",
-    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}，已選取「{selectedSubMenuItemName}」",
     "_%n word_::_%n words_" : ["%n 個字"],
     "_%n char_::_%n chars_" : ["%n 個字元"],
+    "Remaining actions" : "剩餘動作",
     "Editor actions" : "編輯器動作",
     "Formatting menu bar" : "格式化選項選單列",
-    "Remaining actions" : "剩餘動作",
+    "Translate from {language}" : "從 {language} 翻譯",
+    "Translate to {language}" : "翻譯為 {language}",
+    "Translation failed" : "翻譯失敗",
     "To translate individual parts of the text, select it before using the translate function." : "要翻譯部份文字，請在使用翻譯功能前選取該部份。",
     "Translate from" : "翻譯從",
     "Select language" : "選擇語言",
     "Text to translate from" : "要翻譯的文字",
     "to" : "收件者",
+    "Translate to" : "翻譯至",
     "Translated text result" : "翻譯文字結果",
     "Replace" : "置換",
     "Insert" : "插入",
-    "Detect language" : "偵測語言",
-    "Translate from {language}" : "從 {language} 翻譯",
-    "Translate to {language}" : "翻譯為 {language}",
-    "Translation failed" : "翻譯失敗",
     "No emoji found" : "找不到表情符號",
     "No command found" : "找不到指令",
     "No user found" : "找不到使用者",
     "No suggestion found" : "找不到建議",
+    "Upload" : "上傳",
+    "Insert Table" : "插入表格",
+    "Smart Picker" : "智慧型挑選器",
     "Edit" : "編輯",
     "Copy code block" : "複製程式碼區塊",
     "Copy code" : "複製程式碼",
@@ -144,11 +162,10 @@ OC.L10N.register(
     "Diagram" : "圖表",
     "Both" : "皆是",
     "Mermaid documentation" : "Mermaid 文件",
-    "Link to this section" : "連結至此節",
-    "Delete this attachment" : "刪除此附件",
-    "Delete this image" : "刪除此圖片",
     "Failed to load" : "載入失敗",
     "Could not find image in attachments list." : "在附件清單中找不到影像。",
+    "Delete this attachment" : "刪除此附件",
+    "Delete this image" : "刪除此圖片",
     "Add row before" : "在前面新增列",
     "Add row after" : "在後面新增列",
     "Delete this row" : "刪除此列",
@@ -159,43 +176,56 @@ OC.L10N.register(
     "Add column after" : "在後面新增欄",
     "Delete this column" : "刪除此欄",
     "Delete this table" : "刪除此表格",
+    "Add row below" : "在下方新增列",
     "Show folder description" : "顯示資料夾描述",
     "Hide outline" : "隱藏大綱",
     "Show outline" : "顯示大綱",
-    "Undo" : "復原",
-    "Redo" : "重作",
+    "Done" : "完成",
     "Headings" : "標題",
     "Heading 2" : "標題 2",
     "Heading 3" : "標題 3",
     "Heading 4" : "標題 4",
     "Heading 5" : "標題 5",
+    "Lists" : "清單",
     "To-Do list" : "待辦事項清單",
-    "Insert link" : "插入連結",
-    "Callouts" : "標記",
-    "Info" : "資訊",
-    "Success" : "成功",
-    "Warning" : "警告",
-    "Danger" : "危險",
+    "Increase indentation" : "增加縮排",
+    "Decrease indentation" : "減少縮排",
+    "Blocks" : "區塊",
+    "Info callout" : "資訊標記",
+    "Success callout" : "成功標記",
+    "Warning callout" : "警告標記",
+    "Danger callout" : "危險標記",
     "Table" : "表格",
-    "Insert emoji" : "插入表情符號",
+    "Details" : "詳細資訊",
+    "Insert link" : "插入連結",
     "Insert attachment" : "插入附件",
     "Command" : "指令",
-    "Control" : "控制",
+    "Ctrl" : "Ctrl",
     "Option" : "選項",
     "Formatting" : "文字樣式",
-    "Smart picker" : "智慧型挑選器",
-    "Add notes, lists or links …" : "加入筆記、清單或連結…",
+    "Select file or folder to link to" : "選取要連結的檔案或資料夾",
     "Add folder description" : "新增資料夾描述",
     "\"{name}\" already exist!" : "「{name}」已存在！",
     "Created \"{name}\"" : "已建立「{name}」",
     "Copied to the clipboard" : "已複製到剪貼簿",
     "Could not copy to the clipboard" : "無法複製到剪貼簿",
     "Front matter" : "前言",
-    "Pick plain text files" : "挑選純文字檔",
-    "Source language" : "來源語言",
-    "Target language" : "目標語言",
-    "e.g. php, javascript, json, ..." : "例如：php、javascript、json 等",
-    "Show rich workspaces" : "顯示較多功能的工作區",
-    "Add description" : "新增描述"
+    "Link to this section" : "連結至此節",
+    "Use current version" : "使用目前版本",
+    "Use the saved version" : "使用儲存版本",
+    "Document has been changed outside of the editor. The changes cannot be applied" : "文件已在編輯器外變更。無法套用變更。",
+    "Document could not be loaded. Please check your internet connection." : "無法載入文件。請檢查您的網路連線。",
+    "Document idle for {timeout} minutes, click to continue editing" : "文件已閒置 {timeout} 分鐘。點選以繼續編輯",
+    "Show author colors" : "顯示作者顏色",
+    "Author colors are only shown until everyone has closed the document." : "僅在所有人都關閉文件前才顯示文件顏色。",
+    "Detect language" : "偵測語言",
+    "Callouts" : "標記",
+    "Info" : "資訊",
+    "Success" : "成功",
+    "Warning" : "警告",
+    "Danger" : "危險",
+    "Control" : "控制",
+    "Add notes, lists or links …" : "加入筆記、清單或連結…",
+    "Start writing, or try '/' to add, '@' to mention…" : "開始撰寫，或試試看「/」新增、「@」提及……"
 },
 "nplurals=1; plural=0;");
