@@ -45,9 +45,7 @@ use OCA\User_LDAP\Exceptions\NotOnLDAP;
 use OCA\User_LDAP\User\DeletedUsersIndex;
 use OCA\User_LDAP\User\OfflineUser;
 use OCA\User_LDAP\User\User;
-use OCP\IConfig;
 use OCP\IUserBackend;
-use OCP\IUserSession;
 use OCP\Notification\IManager as INotificationManager;
 use OCP\User\Backend\ICountMappedUsersBackend;
 use OCP\User\Backend\ICountUsersBackend;
@@ -56,7 +54,6 @@ use OCP\UserInterface;
 use Psr\Log\LoggerInterface;
 
 class User_LDAP extends BackendUtility implements IUserBackend, UserInterface, IUserLDAP, ICountUsersBackend, ICountMappedUsersBackend, IProvideEnabledStateBackend {
-	protected IConfig $ocConfig;
 	protected INotificationManager $notificationManager;
 	protected UserPluginManager $userPluginManager;
 	protected LoggerInterface $logger;
@@ -64,15 +61,12 @@ class User_LDAP extends BackendUtility implements IUserBackend, UserInterface, I
 
 	public function __construct(
 		Access $access,
-		IConfig $ocConfig,
 		INotificationManager $notificationManager,
-		IUserSession $userSession,
 		UserPluginManager $userPluginManager,
 		LoggerInterface $logger,
 		DeletedUsersIndex $deletedUsersIndex,
 	) {
 		parent::__construct($access);
-		$this->ocConfig = $ocConfig;
 		$this->notificationManager = $notificationManager;
 		$this->userPluginManager = $userPluginManager;
 		$this->logger = $logger;
@@ -361,10 +355,9 @@ class User_LDAP extends BackendUtility implements IUserBackend, UserInterface, I
 		if (!is_null($userExists)) {
 			return (bool)$userExists;
 		}
-		//getting dn, if false the user does not exist. If dn, he may be mapped only, requires more checking.
-		$user = $this->access->userManager->get($uid);
+		$userExists = $this->access->userManager->exists($uid);
 
-		if (is_null($user)) {
+		if (!$userExists) {
 			$this->logger->debug(
 				'No DN found for '.$uid.' on '.$this->access->connection->ldapHost,
 				['app' => 'user_ldap']
@@ -650,7 +643,6 @@ class User_LDAP extends BackendUtility implements IUserBackend, UserInterface, I
 							$uuid,
 							true
 						);
-						$this->access->cacheUserExists($username);
 					} else {
 						$this->logger->warning(
 							'Failed to map created LDAP user with userid {userid}, because UUID could not be determined',
@@ -682,7 +674,7 @@ class User_LDAP extends BackendUtility implements IUserBackend, UserInterface, I
 		return $enabled;
 	}
 
-	public function getDisabledUserList(?int $limit = null, int $offset = 0): array {
+	public function getDisabledUserList(?int $limit = null, int $offset = 0, string $search = ''): array {
 		throw new \Exception('This is implemented directly in User_Proxy');
 	}
 }
