@@ -5,12 +5,14 @@ OC.L10N.register(
     "File is too big" : "Re vras eo ar restr",
     "The selected file is not an image." : "N'eo ket ur skeudenn ar restr choazet.",
     "The selected file cannot be read." : "N'eo ket posubl lenn ar restr choazet.",
+    "The file was uploaded" : "Kaset eo bet ar restr",
+    "No file was uploaded" : "N'eus restr ebet a zo bet kaset",
     "Invalid file provided" : "Ar restr roet n'eo ket unan aotreet",
     "No image or file provided" : "Skeudenn pe restr roet ebet",
     "Unknown filetype" : "N'eo ket anavezet stumm ar restr",
     "An error occurred. Please contact your admin." : "Ur fazi a zo bet. Galvit o merour mar-plij.",
     "Invalid image" : "N'eo ket aotreet ar skeudenn",
-    "No temporary profile picture available, try again" : "N'ez eus skeudenn trolinenn vak ebet, klaskit adarre",
+    "No temporary profile picture available, try again" : "N'ez eus skeudenn brofil vak ebet, klaskit adarre",
     "No crop data provided" : "Roadenn sternglotadur ebet",
     "No valid crop data provided" : "N'ez eus roadenn sternglotadur mat ebet",
     "Crop is not square" : "Ar sternglotadur n'eo ket ur c'harrez",
@@ -34,7 +36,6 @@ OC.L10N.register(
     "Repair info:" : "Keleier adaozañ :",
     "Repair warning:" : "Kemennadenn adaozañ :",
     "Repair error:" : "Fazi adaozañ :",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Mar-plij, implijit al linenn-urzh adneveziñ peogwir eo disaotreet an adneveziñ otomatek e-barzh config.php.",
     "Turned on maintenance mode" : "Lakaet eo ar mod trezalc'hiñ war elum",
     "Turned off maintenance mode" : "Lazhet eo ar mod trezalc'hiñ",
     "Maintenance mode is kept active" : "Mod trezalc'hiñ o labourat",
@@ -49,112 +50,96 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (diglot)",
     "The following apps have been disabled: %s" : "Disaotreet eo bet ar meziantoù-mañ : %s",
     "Already up to date" : "Adnevezet dija",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Ho servijour web n'eo ket bet staliet c'hoazh evit aotreañ ar c'hempredañ, peogwir e seblant etrefas WabDAV bezañ torret.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ne seblant ket bezañ staliet mat evit goulenn d'ar sistem argemennoù endro. An amprouenn gant getenv(\"PATH\") a ro ur respont goullo.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Aotreet a zo bet ar stumm lenn-nemetken. Ampechiñ a ra cheñch stummoù dre an etrefas-web. Ouzhpenn-se, ar restr en deus ezhomm bezañ adlakaet da  vezañ embannapl dre dorn evit pep adneveziñ.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Ho roadennoù-diaz ne droont ket gant al live \"READ COMMITTED\". Kudennoù a zo posupl kaout pa vez graet meur a ober war an dro.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "N'eus ket eus ar modul PHP \"fileinfo\". Gwelloc'h eo aotreañ ar modul-mañ evit kaout an disoc'hoù gwellañ evit dizoloeiñ ar stumm MIME.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ne oa ket posupl ober al labour Cron dre CLI. Ar gudenn deknikel-mañ a zo deuet war wel :",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "N'eo ket posupl implijout arc’hwel PHP \"set_time_limit\". Galout a ra ar gudenn-se herzel skriptoù e-kreiz o labour, terriñ ar staliadur. Aotreañ an arc'hwel a zo aliet-mat.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Ho PHP ne zoug ket FreeType, terriñ ar skeudennoù trolinenn ha stummoù an etrefas.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Ar roll \"{indexName}\" a vank en daolenn \"{tableName}\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Mankout a ra rollioù er roadenn-diaz. Abalamour e kemer amzer ouzhpennañ rollioù e taolennoù bras, n'int ket bet lakaet en un doare otomatek. En ul lakaat da dreiñ \"occ db:add-missing-indices\" eo posupl ouzhpennañ ar rollioù a vank gant an dorn pa vo an azgoulenn o treiñ. Ur wech ar rollioù ouzhpennet, goulennoù savet d'an taolennoù a vo buanaet.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Ar golonenn diret \"{columnName}\" a vank en daolenn \"{tableName}\".",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankout a ra kolonennoù er roadennoù-diaz dibabapl. Abalamour e kemer amzer ouzhpennañ kolonennoù e taolennoù bras, n'int ket bet lakaet en un doare otomatek. En ul lakaat da dreiñ \"occ db:add-missing-columns\" eo posupl ouzhpennañ ar c'holonennoù a vank gant an dorn pa vo an azgoulenn o treiñ. Ur wech ouzhpennet ar c'holonennoù, goulennoù savet d'an taolennoù a vo buanaet.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "An etrefas a vank dezhañ moduloù PHP aliet. Evit gwellaat ar mont en dro hag ar c'heverlec’hded ez eo kinniget kenañ o staliañ.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite a vez implijet evel ur backend ar roadenoù-diaz. Evit staliadurioù brasoc'h e vez aliet cheñch d'ur backend roadennoù-diaz all.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Kinniget kennañ pa vez implijet ar c'hliant burev evit kempredañ ar restroù.",
-    "The PHP memory limit is below the recommended value of 512MB." : "Bevenn memor PHP a zo dindan an hini kinniget eus 512MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Touliadoù meziant zo a zo dalc'het gant un implijour diseñvel eus ar servijour web. M'az eo bet stalied ar meziant gant an dorn eo normal. Gwiriit an aotreoù an teuliadoù meziant mañ:",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "An azgoulenn a implij  un dra diazezed war S3 evel e bern pennañ. Ar restroù pellkaset a vez  bernied ebit point war ar servijour, setut perak eo kinniget kaout 50 GB plass dieub e teuliad PHP temp. Gwiriit ar gazetenn evit munudoù an hent hag ar plass dieub. Evit gwellat ar blass, cheñchit an teuliad amzeriel e-barzh php.ini pa roit muioc'h a blass en hent.",
     "Error occurred while checking server setup" : "Ur vazi a zo bet pa omp o gwiriañ staliadur ar servijour",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Penn HTTP \"{header}\" n'eo ket stumm \"{expected}\". Posuple eo bezha ur gudenn surentez pe prevezted, kinniget eo cheñch ar stumm mañ.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Penn HTTP \"{header}\" n'eo ket stumm \"{expected}\". Perzhioù zo na labouro ket mat, kinniget eo cheñch ar stumm mañ.",
     "unknown text" : "testenn dianv",
     "Hello world!" : "Demat d'ar bed !",
     "sunny" : "heoliek",
-    "Hello {name}, the weather is {weather}" : "Demat {name}, {weather} eo an amzer",
-    "Hello {name}" : "Demat {name}",
+    "Hello {name}, the weather is {weather}" : "Demat deoc'h {name}, {weather} eo an amzer",
+    "Hello {name}" : "Demat deoc'h {name}",
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Setu disoc'hoù o enklask<script>alert(1)</script></strong>",
     "new" : "nevez",
-    "_download %n file_::_download %n files_" : ["O pellgargañ %n restr","O pellgargañ %n restr","O pellgargañ %n restr","O pellgargañ %n restr","O pelgargañ %n restr"],
+    "_download %n file_::_download %n files_" : ["O pellgargañ %n restr","O pellgargañ %n restr","O pellgargañ %n restr","O pellgargañ %n restr","O pellgargañ %n restr"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "An adnevezadenn a zo o treiñ, na zilezik ket ar bajenn, m'o all e hel beza troc'het an oberenn war endroioù zo.",
     "Update to {version}" : "Oc'h adneveziñ da {version}",
     "An error occurred." : "Ur fazi a zo bet.",
     "Please reload the page." : "Mar-plij adkargit ar bajenn",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Graet eo bet an adnevesadenn; Evit muioc'h a titouroù <a href=\"{url}\">sellit ouzh gemenadenoù ar forum</a> diwar benn ze.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "An adnevesadenn a zo bet c'hwitet. Mar-plij, kemenit <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nexcloud community</a> eus ar gudenn.",
+    "Apps" : "Meziant",
     "More apps" : "Muioc'h a veziantoù",
+    "No" : "Nan",
+    "Yes" : "Ya",
+    "Searching …" : "O klask ...",
+    "Start typing to search" : "Krogit da skrivañ evit klask",
+    "Today" : "Hiziv",
+    "Date" : "Deiz",
+    "Search people" : "Klask tud",
+    "People" : "Tud",
+    "Load more results" : "Kagañ muioc'h a disoc'hoù",
     "Log in" : "Kennaskañ",
-    "Logging in …" : "O kennsakañ...",
+    "Logging in …" : "O kennaskañ…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Gwelet on eus eo bet klasket mon-tre dro dre o IP. Ne vo posuple deoc'h klask en dro a-benn 30 eilenn.",
     "Server side authentication failed!" : "Dilesa kostez servijour c'hwited !",
     "Please contact your administrator." : "Mar-plij galvit o merour",
     "An internal error occurred." : "Ur fazi diabarzh a zo bet.",
     "Please try again or contact your administrator." : "Mar-plij, klaskit en dro pe galvit o merour.",
     "Password" : "Ger-tremen",
-    "Wrong username or password." : "Anv-implijader pe ger-tremen direizh",
-    "User disabled" : "Implijer disaotreet",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Gwelet on eus eo bet klasket mon-tre dro dre o IP. Ne vo posuple deoc'h klask en dro a-benn 30 eilenn.",
-    "Username or email" : "Anv implijer pe bostel",
+    "Log in with a device" : "Mon-tre gan un ardivink",
     "Your account is not setup for passwordless login." : "N'eo ket arventennet ho kont evit kennaskañ hep ger-tremen.",
-    "Passwordless authentication is not supported in your browser." : "Ne vez ket degemeret gant ho furcher an anaouadur hep ger-tremen.",
     "Passwordless authentication is only available over a secure connection." : "Dilesa hep ger-tremen a vez kinniget fant ur c'henstagadur sur nemetken.",
+    "Passwordless authentication is not supported in your browser." : "Ne vez ket degemeret gant ho furcher an anaouadur hep ger-tremen.",
     "Reset password" : "Cheñch ger-tremen",
-    "If it is not there ask your local administrator." : "M'a n'eo ket amañ, goulennit o merour lec'h.",
-    "Couldn't send reset email. Please contact your administrator." : "N'eo ket posuple kas ar postel adober. Mar-plij, kelaouit o merour.",
     "Back to login" : "Distro d'ar c'hennask",
+    "Couldn't send reset email. Please contact your administrator." : "N'eo ket posuple kas ar postel adober. Mar-plij, kelaouit o merour.",
     "New password" : "Ger-tremen nevez",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Sifret eo ar restr. ne vo ket posupl deoc'h adtapout ho roadenno goude bezhañ cheñchet ho ger-tremenn. Ma n'oc'h ket sur petra ober, goulenit d'ho merour a raok kendec'hel. C'hoant ho peus kendec'hel ?",
     "I know what I'm doing" : "Gouzout a ran petra a ran",
     "Resetting password" : "Oc'h adtermeniñ ar ger-tremen",
-    "Recommended apps" : "Meziantoù kinniget",
-    "Loading apps …" : "O kargañ ar meziant",
-    "Installing apps …" : "O stallia ar meziant ...",
-    "App download or installation failed" : "Pellgargan pe staliadur ar meziant c'hwited",
-    "Skip" : "Tremen",
-    "Install recommended apps" : "Staliit ar meziantoù kinniget",
     "Schedule work & meetings, synced with all your devices." : "Implij amzer & emvodoù, kemprenet gant toud o ardivinkoù.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Kavit o mignoned ha genseurted en ul lec'h, hep reiñ o ditouroù prevez.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Ur meziant email simpl enfammet gant Restroù, Darempredoù ha Deizataer.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chattañ, pellgomzadennoù video, rannañ skramm, emvodoù dre linnen, ha web brezegennoù - gant o furcherha gant o meziantoù pellgomzerioù-hezoug.",
-    "Forgot password?" : "Ger-tremen ankouaet?",
-    "Log in with a device" : "Mon-tre gan un ardivink",
-    "Back" : "Distro",
-    "Reset search" : "Adkregiñ an enklask",
-    "No results for {query}" : "Disoc'h ebet evit {query}",
-    "Start typing to search" : "Krogit da skrivañ evit klask",
-    "Loading more results …" : "O kargañ muioc'h a zisoc'hoù ...",
-    "Load more results" : "Kagañ muioc'h a disoc'hoù",
-    "Search" : "Klask",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Lakait {minSearchLength} arouez pe muioc'h evit klask","Lakait {minSearchLength} arouez pe muioc'h evit klask","Lakait {minSearchLength} arouez pe muioc'h evit klask","Lakait {minSearchLength} arouez pe muioc'h evit klask","Lakait  {minSearchLength} arouez pe muioc'h evit klask"],
-    "Search {types} …" : "Klask {types} ...",
-    "Settings" : "Arventennoù",
-    "Could not load your contacts" : "N'eo ket posuple kargañ an darempredoù",
-    "Search contacts …" : "Klask darempred ...",
-    "No contacts found" : "Darmpred ebet kavet",
-    "Show all contacts …" : "Diskwel tout an darempredoù ...",
-    "Install the Contacts app" : "Stalliaén ar meziant darempredoù",
+    "Recommended apps" : "Meziantoù kinniget",
+    "Loading apps …" : "O kargañ ar meziant",
+    "App download or installation failed" : "Pellgargan pe staliadur ar meziant c'hwited",
+    "Skip" : "Tremen",
+    "Installing apps …" : "O stallia ar meziant ...",
+    "Install recommended apps" : "Staliit ar meziantoù kinniget",
+    "Settings menu" : "Roll-mezioù an arventennoù",
     "Loading your contacts …" : "O kargañ o darempredoù",
     "Looking for {term} …" : "O klask {term} ...",
-    "No" : "Nan",
-    "Yes" : "Ya",
-    "No files in here" : "Restr ebet amañ",
-    "New folder" : "Heuliad nevez",
-    "No more subfolders in here" : "N'ez eus ket isteuliadoù all amañ",
-    "Name" : "Anv",
-    "Size" : "Ment",
-    "Modified" : "Cheñchet",
-    "\"{name}\" is an invalid file name." : "N'eo ket \"{name}\" un anv restr aotreet.",
-    "File name cannot be empty." : "N'hall ket anv ur restr bezañ goullo.",
-    "\"/\" is not allowed inside a file name." : "N'eo ket aotreet \"/\" e anv ur restr.",
-    "\"{name}\" is not an allowed filetype" : "N'eo ket \"{name}\" un doare restr aotreet",
-    "{newName} already exists" : "{newName} zo anezhañ c'hoazh",
+    "Reset search" : "Adkregiñ an enklask",
+    "Search contacts …" : "Klask darempred ...",
+    "Could not load your contacts" : "N'eo ket posuple kargañ an darempredoù",
+    "No contacts found" : "Darmpred ebet kavet",
+    "Install the Contacts app" : "Stalliaén ar meziant darempredoù",
+    "Search" : "Klask",
+    "No results for {query}" : "Disoc'h ebet evit {query}",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Lakait {minSearchLength} arouez pe muioc'h evit klask","Lakait {minSearchLength} arouez pe muioc'h evit klask","Lakait {minSearchLength} arouez pe muioc'h evit klask","Lakait {minSearchLength} arouez pe muioc'h evit klask","Lakait  {minSearchLength} arouez pe muioc'h evit klask"],
+    "Loading more results …" : "O kargañ muioc'h a zisoc'hoù ...",
+    "Forgot password?" : "Ger-tremen ankouaet?",
+    "Back" : "Distro",
+    "Security warning" : "Kemmenadenn surentez",
+    "Storage & database" : "Lec'h renkañ ha roadennoù-diaz",
+    "Data folder" : "Teuliat roadennoù",
+    "Install and activate additional PHP modules to choose other database types." : "Lakaat ha difraeañ molladoù PHP ouzhpenn evit dibab doare roadennoù-diaz all",
+    "For more details check out the documentation." : "Sellit ouz an dielladur evit munudoù ouzhpenn.",
+    "Performance warning" : "Diwallit ouzh mont en dro",
+    "You chose SQLite as database." : "Choazet o peus SQLite evel roadennoù-diaz.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite a zlefe beahñ implijet evit azgoulennoù bihañ ha/pe dioren. Kinniget eo kemer ur backend roadennoù-diaz all evit ar c'hendec'h.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "M'a vez implijet ar c'hliant evit ar c'hemprenañ, kinniget eo implij un dra kreñvoc'h eget SQLite",
+    "Database user" : "Roadennoù-diaz an implijourien",
+    "Database password" : "Roadennoù-diaz ar gerioù-trermen",
+    "Database name" : "Roadennoù-diaz an anvioù",
+    "Database tablespace" : "Lec'h berniañ ar roadennoù-diaz",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lakit an niverenn porzh gant an anv ostiz (skouer, localhost:5432).",
+    "Database host" : "Roadenn-diaz ostiz",
+    "Need help?" : "Sikour o po ?",
+    "See the documentation" : "Sellit ouz an dielladur",
+    "Search {types} …" : "Klask {types} ...",
     "Choose" : "Dibab",
     "Copy" : "Eilañ",
     "Move" : "Diplasañ",
-    "Error loading file picker template: {error}" : "Ur fazi a zo bet en ur c'hargañ ar choazer eskelet restr : {error}",
     "OK" : "OK",
-    "Error loading message template: {error}" : "Ur fazi zo bet pa voe karget stumm skouer ar gemenadenn : [error]",
     "read-only" : "lennable nemetken",
     "_{count} file conflict_::_{count} file conflicts_" : ["{count} diemglev restr","{count} diemglev restr","{count} diemglev restr","{count} diemglev restr","{count} diemglev restr"],
     "One file conflict" : "Diemglev gant ur restr",
@@ -162,19 +147,12 @@ OC.L10N.register(
     "Already existing files" : "Bez ez eus dija eus ar rentr",
     "Which files do you want to keep?" : "Peseurt restroù o peus c'houant gouarn",
     "If you select both versions, the copied file will have a number added to its name." : "M'a choazit an daou stumm, an restr eilet en do un niver ouzhenned war e anv",
-    "Cancel" : "Arrest",
+    "Cancel" : "Nullañ",
     "Continue" : "Kendec'hel",
     "(all selected)" : "(dibab pep tra)",
     "({count} selected)" : "({count} dibabet)",
     "Error loading file exists template" : "Ur fazi zo bet pa voe karget ar restr",
-    "Pending" : "O c'hortoz",
-    "Copy to {folder}" : "Eilan e {folder}",
-    "Move to {folder}" : "Diblasañ da {folder}",
     "Saving …" : "Orc'h enrolliñ",
-    "Authentication required" : "Eus un dilesa ez eus ezhomp",
-    "This action requires you to confirm your password" : "An ober-mañ a c'houlenn e kadarnfec'h ho ker-tremen",
-    "Confirm" : "Kadarnañ",
-    "Failed to authenticate, try again" : "Dilesa c'hwitet, klaskit en dro",
     "seconds ago" : "eilenn zo",
     "Connection to server lost" : "Kelet eo bet ar c'henstagañ gant ar servijour",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ur gudenn zo evit kargañ ar bajenn, adkargit a ben %n eilenn","Ur gudenn zo evit kargañ ar bajenn, adkargit a ben %n eilenn","Ur gudenn zo evit kargañ ar bajenn, adkargit a ben %n eilenn","Ur gudenn zo evit kargañ ar bajenn, adkargit a ben %n eilenn","Ur gudenn zo evit kargañ ar bajenn, adkargit a ben %n eilenn"],
@@ -189,11 +167,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Skrivit evit klask ar raktresoù dija krouet",
     "New in" : "Nevez e-bazh",
     "View changelog" : "Sellet ar changelog",
-    "Very weak password" : "Ger-tremen skanv kenan",
-    "Weak password" : "Ger-tremen skanv",
-    "So-so password" : "Ger-tremen skañvig",
-    "Good password" : "Ger-tremen mat",
-    "Strong password" : "Ger-tremen kreñv",
     "No action available" : "Oberen ebet posuple",
     "Error fetching contact actions" : "Ur fazi a zo bet en ur tapout an darempred",
     "Non-existing tag #{tag}" : "N'ez eus ket eus ar c'hlav #{tag}",
@@ -203,8 +176,7 @@ OC.L10N.register(
     "Collaborative tags" : "Klav rannet",
     "No tags found" : "Klav ebet kavet",
     "Personal" : "Personel",
-    "Users" : "Implijer",
-    "Apps" : "Meziant",
+    "Accounts" : "Kontoù",
     "Admin" : "Merour",
     "Help" : "Skoazell",
     "Access forbidden" : "N'oc'h ket aotreet tremen",
@@ -219,58 +191,29 @@ OC.L10N.register(
     "Technical details" : "Munidoù teknikel",
     "Remote Address: %s" : "Chom-loc'h pell : %s",
     "Request ID: %s" : "ID goulennet : %s",
-    "Type: %s" : "Stumm : %s",
+    "Type: %s" : "Seurt: %s",
     "Code: %s" : "Kod : %s",
     "Message: %s" : "Kemenadenn : %s",
     "File: %s" : "Restr : %s",
     "Line: %s" : "Linenn :%s",
     "Trace" : "Trace",
-    "Security warning" : "Kemmenadenn surentez",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "O teuliad ha restroù rouadennoù a zo posuple tizhout a dalek ar roaedad, peogwir ne gerzh ket ar restr .htaccess.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Evit kaout titouroù diwar benn penaos stumman mat o servijour, sellit ouz an <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dielvadur</a> mar-plij.",
-    "Create an <strong>admin account</strong>" : "Krouiñ ur <strong>c'hont merour</strong>",
-    "Username" : "anv implijer",
-    "Show password" : "Diskouez ar ger-tremen",
-    "Storage & database" : "Lec'h renkañ ha roadennoù-diaz",
-    "Data folder" : "Teuliat roadennoù",
-    "Configure the database" : "Stumman ar roadennoù-diaz",
-    "Only %s is available." : "%s digarg nemetken",
-    "Install and activate additional PHP modules to choose other database types." : "Lakaat ha difraeañ molladoù PHP ouzhpenn evit dibab doare roadennoù-diaz all",
-    "For more details check out the documentation." : "Sellit ouz an dielladur evit munudoù ouzhpenn.",
-    "Database user" : "Roadennoù-diaz an implijourien",
-    "Database password" : "Roadennoù-diaz ar gerioù-trermen",
-    "Database name" : "Roadennoù-diaz an anvioù",
-    "Database tablespace" : "Lec'h berniañ ar roadennoù-diaz",
-    "Database host" : "Roadenn-diaz ostiz",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lakit an niverenn porzh gant an anv ostiz (skouer, localhost:5432).",
-    "Performance warning" : "Diwallit ouzh mont en dro",
-    "You chose SQLite as database." : "Choazet o peus SQLite evel roadennoù-diaz.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite a zlefe beahñ implijet evit azgoulennoù bihañ ha/pe dioren. Kinniget eo kemer ur backend roadennoù-diaz all evit ar c'hendec'h.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "M'a vez implijet ar c'hliant evit ar c'hemprenañ, kinniget eo implij un dra kreñvoc'h eget SQLite",
-    "Need help?" : "Sikour o po ?",
-    "See the documentation" : "Sellit ouz an dielladur",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Seblant a ra bezhañ emaoc'h o adstaliañ Nexcloud. N'ez eus ket eus arrestr CAN_INSTALL en o teuliad config. Crouit ar restr CAN_INSTALL en teuliad config evit kendec'hel.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "N'eo ket posupl lemel CAN_INSTALL eus an teuliad config. Lamit anezhañ gan an dorn mar-plij.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ezhomp en deus ar meziant eus JavaScript evit kerzhout mat. Mar-plij, {linkstart}aotreit JavaScript{linkend} hag adkargit ar bajenn.",
     "Skip to main content" : "Kit d'an dalc'h penna",
     "Skip to navigation of app" : "Mont d'ar meziant merdeerezh",
+    "Go to %s" : "Mont da %s",
     "Get your own free account" : "Tapit o c'hont digoust",
-    "Contacts" : "Darempredoù",
-    "Contacts menu" : "Roll-mezioù an darempredoù",
-    "Confirm your password" : "Kadarnañ ho ker-tremen",
     "Connect to your account" : "Kevreit gant o c'hont",
     "Please log in before granting %1$s access to your %2$s account." : "Kit-tre a raok reiñ %1$s tremen d'o c'hont %2$s.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "M'a n'oc'h ket o klask stumma un ardivink pe meziant nevez, unan bennak a zo o klask lakaat ac'hanoc'h aotreañ anezho da dizout o roadennoù. M'az eo ze, na gendalc'hit ket, ha kelaouit o merour.",
-    "App token" : "Jedouer meziant",
     "Grant access" : "Reiñ an tremen",
-    "Alternative log in using app token" : "Ur c'hennask disheñvel en ur implij ar jedouer arload",
     "Account access" : "Mont d'ar c'hont",
     "You are about to grant %1$s access to your %2$s account." : "Emaoc'h war-nes reiñ an aotre da \"%1$s\" da dizhout ho kont \"%2$s\".",
     "Account connected" : "Kont kenstaged",
     "Your client should now be connected!" : "O c'hliant a zlefe bezañ kenstaget !",
     "You can close this window." : "Gallout a rit serriñ ar prenestr.",
     "This share is password-protected" : "Al liamm a zo gwarezet gant ur ger-tremen",
-    "Go to %s" : "Mont da %s",
     "Two-factor authentication" : "Eil- elfenn dilesa",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Ar surentez gwelaet a zo bet lkaet war o c'hont. Chazhit un eil elfenn evit an dilesa : ",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ne oa ket posuple kargañ d'an neubeutañ unan aus o doar eil-elfenn dilesa. Kelaouit o merour mar-plij.",
@@ -295,7 +238,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Evit tremen e-biou dale abalamour da ziazezadurioù brasoc'h, e c'hellit implijout an urzh war-lerc’h adalek ho teuliad diazezadur :",
     "Detailed logs" : "Kazetenn munudet",
     "Update needed" : "Un adnevezadur ez eu ezhomp",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Mar-plij, implijit al linnen-urz adneveziñ peogwir m'az eo brazh o azgoulenn gant muioc'h eget 50 implijer.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Evit kavout skoazel, sellit ouzh an <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dielvadur</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Gouzout a rañ eo posupl m'a kendalc'hañ an adnevezaden gant web UI, m'az afe va goulenn en un timeout hag e c'hell koll roadennoù, mes ur backup am eus ha gouzout a rañ penaos adkrouiñ va azgoulenn m'a vez c'huitet.",
     "Upgrade via web on my own risk" : "Adnevesaat dre ar web gant va rislkoù d'in me nemetken",
@@ -303,20 +245,17 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Adnevesaet a vez %s, pez a kemero sur awalc'h amzer ",
     "This page will refresh itself when the instance is available again." : "Ar bajenn a azgreeno e unan pa vo vak an azgoulenn en dro.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kit e darempred gant anr merour reizhad ma chomm ar c'hemenadenn-mañ, pe ma ze war well dic'hortozet ",
-    "[%d / %d]: Checking table %s" : "[%d/%d] : O wiriekaat an daolenn %s",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Ar servijour-mañ n'en deus kenstagadenn Internet ebet o labourat: Ne vez ket tizhet meur a endpoint. Talvezout a ra ne vo ket posupl implijout perzhioù 'zo, evel lakaat ur memor diavaez, kaout keloù diwar-benn ar staliañ pe an adneveziñ. Adtapout restroù ha kas keloù postel ne labouront ket ivez marteze. Kenstagit ar servijour gant an Internet evit implijout ar c'heweriusterioù-mañ.",
-    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "An roadennoù teuliadoù ha restroù a zo marteze posuple bezha tizet dre Internet. Ar restr .htacces na gerzh ket. Kinniget krennañ eo stummañ o servijour web avit ma ne vefe ket tizaple ar roadennoù teuliadoù, pe fival anezhi er maez eus diel gwrizienn ar servijour web.",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Penn HTTP \"{header}\"  n'en deus ket \"{expected}\". Posuple eo bezha ur gudenn surentez pe prevezted, kinniget eo cheñch ar stumm mañ.",
-    "Collaboratively edit office documents." : "Embennit o dielloù office asambless.",
-    "Local document editing back-end used by the Collabora Online app." : "Emban lec'hiet pennañ diell implijet gant ar meziant Collabora Online.",
-    "restricted" : "strizhaet",
-    "invisible" : "diwelus",
-    "File not found" : "N'eo ket bet kavet ar restr",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "N'eo ket posuple kavout ar ragtress war ar servijour. Marteze eo re gozh pe ez eo bet lammet ar rannadenn.",
-    "More" : "Muioc'h",
-    "More apps menu" : "Muioc'h a roll-mezioù meziantoù",
-    "Settings menu" : "Roll-mezioù an arventennoù",
-    "The password is wrong. Try again." : "Direizh eo ger-tremen. Klaskit en-dro.",
-    "Setup two-factor authentication" : "Stummañ un eil-elfenn dilesa"
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chattañ, pellgomzadennoù video, rannañ skramm, emvodoù dre linnen, ha web brezegennoù - gant o furcherha gant o meziantoù pellgomzerioù-hezoug.",
+    "Error loading message template: {error}" : "Ur fazi zo bet pa voe karget stumm skouer ar gemenadenn : [error]",
+    "Very weak password" : "Ger-tremen skanv kenan",
+    "Weak password" : "Ger-tremen skanv",
+    "So-so password" : "Ger-tremen skañvig",
+    "Good password" : "Ger-tremen mat",
+    "Strong password" : "Ger-tremen kreñv",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "O teuliad ha restroù rouadennoù a zo posuple tizhout a dalek ar roaedad, peogwir ne gerzh ket ar restr .htaccess.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Evit kaout titouroù diwar benn penaos stumman mat o servijour, sellit ouz an <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dielvadur</a> mar-plij.",
+    "Show password" : "Diskouez ar ger-tremen",
+    "Configure the database" : "Stumman ar roadennoù-diaz",
+    "Only %s is available." : "%s digarg nemetken"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
