@@ -3,10 +3,12 @@
  * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
  * @copyright Copyright (c) 2017, ownCloud GmbH
  *
+ * @author Christoph Wurst <christoph@winzerhof-wurst.at>
+ * @author Daniel Kesselberg <mail@danielkesselberg.de>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author Julius Härtl <jus@bitgrid.net>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <robin@icewind.nl>
- * @author Roeland Jago Douma <roeland@famdouma.nl>
  *
  * @license AGPL-3.0
  *
@@ -23,56 +25,53 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
-
 namespace OC\DB;
 
 use Doctrine\DBAL\Platforms\OraclePlatform;
-use Doctrine\DBAL\Platforms\PostgreSqlPlatform;
+use Doctrine\DBAL\Platforms\PostgreSQL94Platform;
 use Doctrine\DBAL\Schema\Index;
 use Doctrine\DBAL\Schema\Schema;
 use Doctrine\DBAL\Schema\SchemaException;
 use Doctrine\DBAL\Schema\Sequence;
 use Doctrine\DBAL\Schema\Table;
-use Doctrine\DBAL\Types\Type;
+use Doctrine\DBAL\Types\Types;
 use OC\App\InfoParser;
 use OC\IntegrityCheck\Helpers\AppLocator;
 use OC\Migration\SimpleOutput;
 use OCP\AppFramework\App;
 use OCP\AppFramework\QueryException;
-use OCP\IDBConnection;
+use OCP\DB\ISchemaWrapper;
 use OCP\Migration\IMigrationStep;
 use OCP\Migration\IOutput;
+use OCP\Server;
+use Psr\Log\LoggerInterface;
 
 class MigrationService {
-
-	/** @var boolean */
-	private $migrationTableCreated;
-	/** @var array */
-	private $migrations;
-	/** @var IOutput */
-	private $output;
-	/** @var Connection */
-	private $connection;
-	/** @var string */
-	private $appName;
-	/** @var bool */
-	private $checkOracle;
+	private bool $migrationTableCreated;
+	private array $migrations;
+	private string $migrationsPath;
+	private string $migrationsNamespace;
+	private IOutput $output;
+	private LoggerInterface $logger;
+	private Connection $connection;
+	private string $appName;
+	private bool $checkOracle;
 
 	/**
-	 * MigrationService constructor.
-	 *
-	 * @param $appName
-	 * @param IDBConnection $connection
-	 * @param AppLocator $appLocator
-	 * @param IOutput|null $output
 	 * @throws \Exception
 	 */
-	public function __construct($appName, IDBConnection $connection, IOutput $output = null, AppLocator $appLocator = null) {
+	public function __construct(string $appName, Connection $connection, ?IOutput $output = null, ?AppLocator $appLocator = null, ?LoggerInterface $logger = null) {
 		$this->appName = $appName;
 		$this->connection = $connection;
-		$this->output = $output;
-		if (null === $this->output) {
-			$this->output = new SimpleOutput(\OC::$server->getLogger(), $appName);
+		if ($logger === null) {
+			$this->logger = Server::get(LoggerInterface::class);
+		} else {
+			$this->logger = $logger;
+		}
+		if ($output === null) {
+			$this->output = new SimpleOutput($this->logger, $appName);
+		} else {
+			$this->output = $output;
 		}
 
 		if ($appName === 'core') {
@@ -80,7 +79,7 @@ class MigrationService {
 			$this->migrationsNamespace = 'OC\\Core\\Migrations';
 			$this->checkOracle = true;
 		} else {
-			if (null === $appLocator) {
+			if ($appLocator === null) {
 				$appLocator = new AppLocator();
 			}
 			$appPath = $appLocator->getAppPath($appName);
@@ -97,32 +96,35 @@ class MigrationService {
 				foreach ($info['dependencies']['database'] as $database) {
 					if (\is_string($database) && $database === 'oci') {
 						$this->checkOracle = true;
-					} else if (\is_array($database) && isset($database['@value']) && $database['@value'] === 'oci') {
+					} elseif (\is_array($database) && isset($database['@value']) && $database['@value'] === 'oci') {
 						$this->checkOracle = true;
 					}
 				}
 			}
 		}
+		$this->migrationTableCreated = false;
 	}
 
 	/**
 	 * Returns the name of the app for which this migration is executed
-	 *
-	 * @return string
 	 */
-	public function getApp() {
+	public function getApp(): string {
 		return $this->appName;
 	}
 
 	/**
-	 * @return bool
 	 * @codeCoverageIgnore - this will implicitly tested on installation
 	 */
-	private function createMigrationTable() {
+	private function createMigrationTable(): bool {
 		if ($this->migrationTableCreated) {
 			return false;
 		}
 
+		if ($this->connection->tableExists('migrations') && \OC::$server->getConfig()->getAppValue('core', 'vendor', '') !== 'owncloud') {
+			$this->migrationTableCreated = true;
+			return false;
+		}
+
 		$schema = new SchemaWrapper($this->connection);
 
 		/**
@@ -159,14 +161,13 @@ class MigrationService {
 
 			// Recreate the schema after the table was dropped.
 			$schema = new SchemaWrapper($this->connection);
-
 		} catch (SchemaException $e) {
 			// Table not found, no need to panic, we will create it.
 		}
 
 		$table = $schema->createTable('migrations');
-		$table->addColumn('app', Type::STRING, ['length' => 255]);
-		$table->addColumn('version', Type::STRING, ['length' => 255]);
+		$table->addColumn('app', Types::STRING, ['length' => 255]);
+		$table->addColumn('version', Types::STRING, ['length' => 255]);
 		$table->setPrimaryKey(['app', 'version']);
 
 		$this->connection->migrateToSchema($schema->getWrappedSchema());
@@ -179,7 +180,7 @@ class MigrationService {
 	/**
 	 * Returns all versions which have already been applied
 	 *
-	 * @return string[]
+	 * @return list<string>
 	 * @codeCoverageIgnore - no need to test this
 	 */
 	public function getMigratedVersions() {
@@ -191,24 +192,44 @@ class MigrationService {
 			->where($qb->expr()->eq('app', $qb->createNamedParameter($this->getApp())))
 			->orderBy('version');
 
-		$result = $qb->execute();
+		$result = $qb->executeQuery();
 		$rows = $result->fetchAll(\PDO::FETCH_COLUMN);
 		$result->closeCursor();
 
+		usort($rows, [$this, 'sortMigrations']);
+
 		return $rows;
 	}
 
 	/**
 	 * Returns all versions which are available in the migration folder
-	 *
-	 * @return array
+	 * @return list<string>
 	 */
-	public function getAvailableVersions() {
+	public function getAvailableVersions(): array {
 		$this->ensureMigrationsAreLoaded();
-		return array_map('strval', array_keys($this->migrations));
+		$versions = array_map('strval', array_keys($this->migrations));
+		usort($versions, [$this, 'sortMigrations']);
+		return $versions;
 	}
 
-	protected function findMigrations() {
+	protected function sortMigrations(string $a, string $b): int {
+		preg_match('/(\d+)Date(\d+)/', basename($a), $matchA);
+		preg_match('/(\d+)Date(\d+)/', basename($b), $matchB);
+		if (!empty($matchA) && !empty($matchB)) {
+			$versionA = (int)$matchA[1];
+			$versionB = (int)$matchB[1];
+			if ($versionA !== $versionB) {
+				return ($versionA < $versionB) ? -1 : 1;
+			}
+			return strnatcmp($matchA[2], $matchB[2]);
+		}
+		return strnatcmp(basename($a), basename($b));
+	}
+
+	/**
+	 * @return array<string, string>
+	 */
+	protected function findMigrations(): array {
 		$directory = realpath($this->migrationsPath);
 		if ($directory === false || !file_exists($directory) || !is_dir($directory)) {
 			return [];
@@ -223,17 +244,7 @@ class MigrationService {
 			\RegexIterator::GET_MATCH);
 
 		$files = array_keys(iterator_to_array($iterator));
-		uasort($files, function ($a, $b) {
-			preg_match('/^Version(\d+)Date(\d+)\\.php$/', basename($a), $matchA);
-			preg_match('/^Version(\d+)Date(\d+)\\.php$/', basename($b), $matchB);
-			if (!empty($matchA) && !empty($matchB)) {
-				if ($matchA[1] !== $matchB[1]) {
-					return ($matchA[1] < $matchB[1]) ? -1 : 1;
-				}
-				return ($matchA[2] < $matchB[2]) ? -1 : 1;
-			}
-			return (basename($a) < basename($b)) ? -1 : 1;
-		});
+		usort($files, [$this, 'sortMigrations']);
 
 		$migrations = [];
 
@@ -261,7 +272,7 @@ class MigrationService {
 
 		$toBeExecuted = [];
 		foreach ($availableMigrations as $v) {
-			if ($to !== 'latest' && $v > $to) {
+			if ($to !== 'latest' && ($this->sortMigrations($v, $to) > 0)) {
 				continue;
 			}
 			if ($this->shallBeExecuted($v, $knownMigrations)) {
@@ -325,11 +336,10 @@ class MigrationService {
 	/**
 	 * Return the explicit version for the aliases; current, next, prev, latest
 	 *
-	 * @param string $alias
 	 * @return mixed|null|string
 	 */
-	public function getMigration($alias) {
-		switch($alias) {
+	public function getMigration(string $alias) {
+		switch ($alias) {
 			case 'current':
 				return $this->getCurrentVersion();
 			case 'next':
@@ -345,29 +355,22 @@ class MigrationService {
 		return '0';
 	}
 
-	/**
-	 * @param string $version
-	 * @param int $delta
-	 * @return null|string
-	 */
-	private function getRelativeVersion($version, $delta) {
+	private function getRelativeVersion(string $version, int $delta): ?string {
 		$this->ensureMigrationsAreLoaded();
 
 		$versions = $this->getAvailableVersions();
-		array_unshift($versions, 0);
+		array_unshift($versions, '0');
+		/** @var int $offset */
 		$offset = array_search($version, $versions, true);
 		if ($offset === false || !isset($versions[$offset + $delta])) {
 			// Unknown version or delta out of bounds.
 			return null;
 		}
 
-		return (string) $versions[$offset + $delta];
+		return (string)$versions[$offset + $delta];
 	}
 
-	/**
-	 * @return string
-	 */
-	private function getCurrentVersion() {
+	private function getCurrentVersion(): string {
 		$m = $this->getMigratedVersions();
 		if (count($m) === 0) {
 			return '0';
@@ -377,11 +380,9 @@ class MigrationService {
 	}
 
 	/**
-	 * @param string $version
-	 * @return string
 	 * @throws \InvalidArgumentException
 	 */
-	private function getClass($version) {
+	private function getClass(string $version): string {
 		$this->ensureMigrationsAreLoaded();
 
 		if (isset($this->migrations[$version])) {
@@ -393,25 +394,74 @@ class MigrationService {
 
 	/**
 	 * Allows to set an IOutput implementation which is used for logging progress and messages
-	 *
-	 * @param IOutput $output
 	 */
-	public function setOutput(IOutput $output) {
+	public function setOutput(IOutput $output): void {
 		$this->output = $output;
 	}
 
 	/**
 	 * Applies all not yet applied versions up to $to
-	 *
-	 * @param string $to
-	 * @param bool $schemaOnly
 	 * @throws \InvalidArgumentException
 	 */
-	public function migrate($to = 'latest', $schemaOnly = false) {
+	public function migrate(string $to = 'latest', bool $schemaOnly = false): void {
+		if ($schemaOnly) {
+			$this->output->debug('Migrating schema only');
+			$this->migrateSchemaOnly($to);
+			return;
+		}
+
 		// read known migrations
 		$toBeExecuted = $this->getMigrationsToExecute($to);
 		foreach ($toBeExecuted as $version) {
-			$this->executeStep($version, $schemaOnly);
+			try {
+				$this->executeStep($version, $schemaOnly);
+			} catch (\Exception $e) {
+				// The exception itself does not contain the name of the migration,
+				// so we wrap it here, to make debugging easier.
+				throw new \Exception('Database error when running migration ' . $version . ' for app ' . $this->getApp() . PHP_EOL. $e->getMessage(), 0, $e);
+			}
+		}
+	}
+
+	/**
+	 * Applies all not yet applied versions up to $to
+	 * @throws \InvalidArgumentException
+	 */
+	public function migrateSchemaOnly(string $to = 'latest'): void {
+		// read known migrations
+		$toBeExecuted = $this->getMigrationsToExecute($to);
+
+		if (empty($toBeExecuted)) {
+			return;
+		}
+
+		$toSchema = null;
+		foreach ($toBeExecuted as $version) {
+			$this->output->debug('- Reading ' . $version);
+			$instance = $this->createInstance($version);
+
+			$toSchema = $instance->changeSchema($this->output, function () use ($toSchema): ISchemaWrapper {
+				return $toSchema ?: new SchemaWrapper($this->connection);
+			}, ['tablePrefix' => $this->connection->getPrefix()]) ?: $toSchema;
+		}
+
+		if ($toSchema instanceof SchemaWrapper) {
+			$this->output->debug('- Checking target database schema');
+			$targetSchema = $toSchema->getWrappedSchema();
+			$this->ensureUniqueNamesConstraints($targetSchema, true);
+			if ($this->checkOracle) {
+				$beforeSchema = $this->connection->createSchema();
+				$this->ensureOracleConstraints($beforeSchema, $targetSchema, strlen($this->connection->getPrefix()));
+			}
+
+			$this->output->debug('- Migrate database schema');
+			$this->connection->migrateToSchema($targetSchema);
+			$toSchema->performDropTableCalls();
+		}
+
+		$this->output->debug('- Mark migrations as executed');
+		foreach ($toBeExecuted as $version) {
+			$this->markAsExecuted($version);
 		}
 	}
 
@@ -441,7 +491,7 @@ class MigrationService {
 	protected function createInstance($version) {
 		$class = $this->getClass($version);
 		try {
-			$s = \OC::$server->query($class);
+			$s = \OCP\Server::get($class);
 
 			if (!$s instanceof IMigrationStep) {
 				throw new \InvalidArgumentException('Not a valid migration');
@@ -468,27 +518,28 @@ class MigrationService {
 		$instance = $this->createInstance($version);
 
 		if (!$schemaOnly) {
-			$instance->preSchemaChange($this->output, function() {
+			$instance->preSchemaChange($this->output, function (): ISchemaWrapper {
 				return new SchemaWrapper($this->connection);
 			}, ['tablePrefix' => $this->connection->getPrefix()]);
 		}
 
-		$toSchema = $instance->changeSchema($this->output, function() {
+		$toSchema = $instance->changeSchema($this->output, function (): ISchemaWrapper {
 			return new SchemaWrapper($this->connection);
 		}, ['tablePrefix' => $this->connection->getPrefix()]);
 
 		if ($toSchema instanceof SchemaWrapper) {
 			$targetSchema = $toSchema->getWrappedSchema();
+			$this->ensureUniqueNamesConstraints($targetSchema, $schemaOnly);
 			if ($this->checkOracle) {
 				$sourceSchema = $this->connection->createSchema();
-				$this->ensureOracleIdentifierLengthLimit($sourceSchema, $targetSchema, strlen($this->connection->getPrefix()));
+				$this->ensureOracleConstraints($sourceSchema, $targetSchema, strlen($this->connection->getPrefix()));
 			}
 			$this->connection->migrateToSchema($targetSchema);
 			$toSchema->performDropTableCalls();
 		}
 
 		if (!$schemaOnly) {
-			$instance->postSchemaChange($this->output, function() {
+			$instance->postSchemaChange($this->output, function (): ISchemaWrapper {
 				return new SchemaWrapper($this->connection);
 			}, ['tablePrefix' => $this->connection->getPrefix()]);
 		}
@@ -496,7 +547,29 @@ class MigrationService {
 		$this->markAsExecuted($version);
 	}
 
-	public function ensureOracleIdentifierLengthLimit(Schema $sourceSchema, Schema $targetSchema, int $prefixLength) {
+	/**
+	 * Naming constraints:
+	 * - Tables names must be 30 chars or shorter (27 + oc_ prefix)
+	 * - Column names must be 30 chars or shorter
+	 * - Index names must be 30 chars or shorter
+	 * - Sequence names must be 30 chars or shorter
+	 * - Primary key names must be set or the table name 23 chars or shorter
+	 *
+	 * Data constraints:
+	 * - Tables need a primary key (Not specific to Oracle, but required for performant clustering support)
+	 * - Columns with "NotNull" can not have empty string as default value
+	 * - Columns with "NotNull" can not have number 0 as default value
+	 * - Columns with type "bool" (which is in fact integer of length 1) can not be "NotNull" as it can not store 0/false
+	 * - Columns with type "string" can not be longer than 4.000 characters, use "text" instead
+	 *
+	 * @see https://github.com/nextcloud/documentation/blob/master/developer_manual/basics/storage/database.rst
+	 *
+	 * @param Schema $sourceSchema
+	 * @param Schema $targetSchema
+	 * @param int $prefixLength
+	 * @throws \Doctrine\DBAL\Exception
+	 */
+	public function ensureOracleConstraints(Schema $sourceSchema, Schema $targetSchema, int $prefixLength) {
 		$sequences = $targetSchema->getSequences();
 
 		foreach ($targetSchema->getTables() as $table) {
@@ -504,31 +577,49 @@ class MigrationService {
 				$sourceTable = $sourceSchema->getTable($table->getName());
 			} catch (SchemaException $e) {
 				if (\strlen($table->getName()) - $prefixLength > 27) {
-					throw new \InvalidArgumentException('Table name "'  . $table->getName() . '" is too long.');
+					throw new \InvalidArgumentException('Table name "' . $table->getName() . '" is too long.');
 				}
 				$sourceTable = null;
 			}
 
 			foreach ($table->getColumns() as $thing) {
-				if ((!$sourceTable instanceof Table || !$sourceTable->hasColumn($thing->getName())) && \strlen($thing->getName()) > 30) {
-					throw new \InvalidArgumentException('Column name "'  . $table->getName() . '"."' . $thing->getName() . '" is too long.');
+				// If the table doesn't exist OR if the column doesn't exist in the table
+				if (!$sourceTable instanceof Table || !$sourceTable->hasColumn($thing->getName())) {
+					if (\strlen($thing->getName()) > 30) {
+						throw new \InvalidArgumentException('Column name "' . $table->getName() . '"."' . $thing->getName() . '" is too long.');
+					}
+
+					if ($thing->getNotnull() && $thing->getDefault() === ''
+						&& $sourceTable instanceof Table && !$sourceTable->hasColumn($thing->getName())) {
+						throw new \InvalidArgumentException('Column "' . $table->getName() . '"."' . $thing->getName() . '" is NotNull, but has empty string or null as default.');
+					}
+
+					if ($thing->getNotnull() && $thing->getType()->getName() === Types::BOOLEAN) {
+						throw new \InvalidArgumentException('Column "' . $table->getName() . '"."' . $thing->getName() . '" is type Bool and also NotNull, so it can not store "false".');
+					}
+
+					$sourceColumn = null;
+				} else {
+					$sourceColumn = $sourceTable->getColumn($thing->getName());
 				}
 
-				if ($thing->getNotnull() && $thing->getDefault() === ''
-					&& $sourceTable instanceof Table && !$sourceTable->hasColumn($thing->getName())) {
-					throw new \InvalidArgumentException('Column name "'  . $table->getName() . '"."' . $thing->getName() . '" is NotNull, but has empty string or null as default.');
+				// If the column was just created OR the length changed OR the type changed
+				// we will NOT detect invalid length if the column is not modified
+				if (($sourceColumn === null || $sourceColumn->getLength() !== $thing->getLength() || $sourceColumn->getType()->getName() !== Types::STRING)
+					&& $thing->getLength() > 4000 && $thing->getType()->getName() === Types::STRING) {
+					throw new \InvalidArgumentException('Column "' . $table->getName() . '"."' . $thing->getName() . '" is type String, but exceeding the 4.000 length limit.');
 				}
 			}
 
 			foreach ($table->getIndexes() as $thing) {
 				if ((!$sourceTable instanceof Table || !$sourceTable->hasIndex($thing->getName())) && \strlen($thing->getName()) > 30) {
-					throw new \InvalidArgumentException('Index name "'  . $table->getName() . '"."' . $thing->getName() . '" is too long.');
+					throw new \InvalidArgumentException('Index name "' . $table->getName() . '"."' . $thing->getName() . '" is too long.');
 				}
 			}
 
 			foreach ($table->getForeignKeys() as $thing) {
 				if ((!$sourceTable instanceof Table || !$sourceTable->hasForeignKey($thing->getName())) && \strlen($thing->getName()) > 30) {
-					throw new \InvalidArgumentException('Foreign key name "'  . $table->getName() . '"."' . $thing->getName() . '" is too long.');
+					throw new \InvalidArgumentException('Foreign key name "' . $table->getName() . '"."' . $thing->getName() . '" is too long.');
 				}
 			}
 
@@ -537,37 +628,127 @@ class MigrationService {
 				$indexName = strtolower($primaryKey->getName());
 				$isUsingDefaultName = $indexName === 'primary';
 
-				if ($this->connection->getDatabasePlatform() instanceof PostgreSqlPlatform) {
+				if ($this->connection->getDatabasePlatform() instanceof PostgreSQL94Platform) {
 					$defaultName = $table->getName() . '_pkey';
 					$isUsingDefaultName = strtolower($defaultName) === $indexName;
 
 					if ($isUsingDefaultName) {
 						$sequenceName = $table->getName() . '_' . implode('_', $primaryKey->getColumns()) . '_seq';
-						$sequences = array_filter($sequences, function(Sequence $sequence) use ($sequenceName) {
+						$sequences = array_filter($sequences, function (Sequence $sequence) use ($sequenceName) {
 							return $sequence->getName() !== $sequenceName;
 						});
 					}
-				} else if ($this->connection->getDatabasePlatform() instanceof OraclePlatform) {
+				} elseif ($this->connection->getDatabasePlatform() instanceof OraclePlatform) {
 					$defaultName = $table->getName() . '_seq';
 					$isUsingDefaultName = strtolower($defaultName) === $indexName;
 				}
 
 				if (!$isUsingDefaultName && \strlen($indexName) > 30) {
-					throw new \InvalidArgumentException('Primary index name  on "'  . $table->getName() . '" is too long.');
+					throw new \InvalidArgumentException('Primary index name on "' . $table->getName() . '" is too long.');
 				}
 				if ($isUsingDefaultName && \strlen($table->getName()) - $prefixLength >= 23) {
-					throw new \InvalidArgumentException('Primary index name  on "'  . $table->getName() . '" is too long.');
+					throw new \InvalidArgumentException('Primary index name on "' . $table->getName() . '" is too long.');
 				}
+			} elseif (!$primaryKey instanceof Index && !$sourceTable instanceof Table) {
+				/** @var LoggerInterface $logger */
+				$logger = \OC::$server->get(LoggerInterface::class);
+				$logger->error('Table "' . $table->getName() . '" has no primary key and therefor will not behave sane in clustered setups. This will throw an exception and not be installable in a future version of Nextcloud.');
+				// throw new \InvalidArgumentException('Table "' . $table->getName() . '" has no primary key and therefor will not behave sane in clustered setups.');
 			}
 		}
 
 		foreach ($sequences as $sequence) {
 			if (!$sourceSchema->hasSequence($sequence->getName()) && \strlen($sequence->getName()) > 30) {
-				throw new \InvalidArgumentException('Sequence name "'  . $sequence->getName() . '" is too long.');
+				throw new \InvalidArgumentException('Sequence name "' . $sequence->getName() . '" is too long.');
 			}
 		}
 	}
 
+	/**
+	 * Ensure naming constraints
+	 *
+	 * Naming constraints:
+	 * - Index, sequence and primary key names must be unique within a Postgres Schema
+	 *
+	 * Only on installation we want to break hard, so that all developers notice
+	 * the bugs when installing the app on any database or CI, and can work on
+	 * fixing their migrations before releasing a version incompatible with Postgres.
+	 *
+	 * In case of updates we might be running on production instances and the
+	 * administrators being faced with the error would not know how to resolve it
+	 * anyway. This can also happen with instances, that had the issue before the
+	 * current update, so we don't want to make their life more complicated
+	 * than needed.
+	 *
+	 * @param Schema $targetSchema
+	 * @param bool $isInstalling
+	 */
+	public function ensureUniqueNamesConstraints(Schema $targetSchema, bool $isInstalling): void {
+		$constraintNames = [];
+		$sequences = $targetSchema->getSequences();
+
+		foreach ($targetSchema->getTables() as $table) {
+			foreach ($table->getIndexes() as $thing) {
+				$indexName = strtolower($thing->getName());
+				if ($indexName === 'primary' || $thing->isPrimary()) {
+					continue;
+				}
+
+				if (isset($constraintNames[$thing->getName()])) {
+					if ($isInstalling) {
+						throw new \InvalidArgumentException('Index name "' . $thing->getName() . '" for table "' . $table->getName() . '" collides with the constraint on table "' . $constraintNames[$thing->getName()] . '".');
+					}
+					$this->logErrorOrWarning('Index name "' . $thing->getName() . '" for table "' . $table->getName() . '" collides with the constraint on table "' . $constraintNames[$thing->getName()] . '".');
+				}
+				$constraintNames[$thing->getName()] = $table->getName();
+			}
+
+			foreach ($table->getForeignKeys() as $thing) {
+				if (isset($constraintNames[$thing->getName()])) {
+					if ($isInstalling) {
+						throw new \InvalidArgumentException('Foreign key name "' . $thing->getName() . '" for table "' . $table->getName() . '" collides with the constraint on table "' . $constraintNames[$thing->getName()] . '".');
+					}
+					$this->logErrorOrWarning('Foreign key name "' . $thing->getName() . '" for table "' . $table->getName() . '" collides with the constraint on table "' . $constraintNames[$thing->getName()] . '".');
+				}
+				$constraintNames[$thing->getName()] = $table->getName();
+			}
+
+			$primaryKey = $table->getPrimaryKey();
+			if ($primaryKey instanceof Index) {
+				$indexName = strtolower($primaryKey->getName());
+				if ($indexName === 'primary') {
+					continue;
+				}
+
+				if (isset($constraintNames[$indexName])) {
+					if ($isInstalling) {
+						throw new \InvalidArgumentException('Primary index name "' . $indexName . '" for table "' . $table->getName() . '" collides with the constraint on table "' . $constraintNames[$thing->getName()] . '".');
+					}
+					$this->logErrorOrWarning('Primary index name "' . $indexName . '" for table "' . $table->getName() . '" collides with the constraint on table "' . $constraintNames[$thing->getName()] . '".');
+				}
+				$constraintNames[$indexName] = $table->getName();
+			}
+		}
+
+		foreach ($sequences as $sequence) {
+			if (isset($constraintNames[$sequence->getName()])) {
+				if ($isInstalling) {
+					throw new \InvalidArgumentException('Sequence name "' . $sequence->getName() . '" for table "' . $table->getName() . '" collides with the constraint on table "' . $constraintNames[$thing->getName()] . '".');
+				}
+				$this->logErrorOrWarning('Sequence name "' . $sequence->getName() . '" for table "' . $table->getName() . '" collides with the constraint on table "' . $constraintNames[$thing->getName()] . '".');
+			}
+			$constraintNames[$sequence->getName()] = 'sequence';
+		}
+	}
+
+	protected function logErrorOrWarning(string $log): void {
+		if ($this->output instanceof SimpleOutput) {
+			$this->output->warning($log);
+		} else {
+			$this->logger->error($log);
+		}
+	}
+
 	private function ensureMigrationsAreLoaded() {
 		if (empty($this->migrations)) {
 			$this->migrations = $this->findMigrations();
