@@ -62,42 +62,23 @@ use function strtr;
  * MonoLog is an example implementing this interface.
  */
 class Log implements ILogger, IDataLogger {
-	private IWriter $logger;
-	private ?SystemConfig $config;
 	private ?bool $logConditionSatisfied = null;
-	private ?Normalizer $normalizer;
-	private ?IRegistry $crashReporters;
-	private ?IEventDispatcher $eventDispatcher;
+	private ?IEventDispatcher $eventDispatcher = null;
+	private int $nestingLevel = 0;
 
-	/**
-	 * @param IWriter $logger The logger that should be used
-	 * @param SystemConfig $config the system config object
-	 * @param Normalizer|null $normalizer
-	 * @param IRegistry|null $registry
-	 */
 	public function __construct(
-		IWriter $logger,
-		SystemConfig $config = null,
-		Normalizer $normalizer = null,
-		IRegistry $registry = null
+		private IWriter $logger,
+		private SystemConfig $config,
+		private ?Normalizer $normalizer = null,
+		private ?IRegistry $crashReporters = null
 	) {
-		// FIXME: Add this for backwards compatibility, should be fixed at some point probably
-		if ($config === null) {
-			$config = \OC::$server->getSystemConfig();
-		}
-
-		$this->config = $config;
-		$this->logger = $logger;
+		// FIXME: php8.1 allows "private Normalizer $normalizer = new Normalizer()," in initializer
 		if ($normalizer === null) {
 			$this->normalizer = new Normalizer();
-		} else {
-			$this->normalizer = $normalizer;
 		}
-		$this->crashReporters = $registry;
-		$this->eventDispatcher = null;
 	}
 
-	public function setEventDispatcher(IEventDispatcher $eventDispatcher) {
+	public function setEventDispatcher(IEventDispatcher $eventDispatcher): void {
 		$this->eventDispatcher = $eventDispatcher;
 	}
 
@@ -106,9 +87,8 @@ class Log implements ILogger, IDataLogger {
 	 *
 	 * @param string $message
 	 * @param array $context
-	 * @return void
 	 */
-	public function emergency(string $message, array $context = []) {
+	public function emergency(string $message, array $context = []): void {
 		$this->log(ILogger::FATAL, $message, $context);
 	}
 
@@ -120,9 +100,8 @@ class Log implements ILogger, IDataLogger {
 	 *
 	 * @param string $message
 	 * @param array $context
-	 * @return void
 	 */
-	public function alert(string $message, array $context = []) {
+	public function alert(string $message, array $context = []): void {
 		$this->log(ILogger::ERROR, $message, $context);
 	}
 
@@ -133,9 +112,8 @@ class Log implements ILogger, IDataLogger {
 	 *
 	 * @param string $message
 	 * @param array $context
-	 * @return void
 	 */
-	public function critical(string $message, array $context = []) {
+	public function critical(string $message, array $context = []): void {
 		$this->log(ILogger::ERROR, $message, $context);
 	}
 
@@ -145,9 +123,8 @@ class Log implements ILogger, IDataLogger {
 	 *
 	 * @param string $message
 	 * @param array $context
-	 * @return void
 	 */
-	public function error(string $message, array $context = []) {
+	public function error(string $message, array $context = []): void {
 		$this->log(ILogger::ERROR, $message, $context);
 	}
 
@@ -159,9 +136,8 @@ class Log implements ILogger, IDataLogger {
 	 *
 	 * @param string $message
 	 * @param array $context
-	 * @return void
 	 */
-	public function warning(string $message, array $context = []) {
+	public function warning(string $message, array $context = []): void {
 		$this->log(ILogger::WARN, $message, $context);
 	}
 
@@ -170,9 +146,8 @@ class Log implements ILogger, IDataLogger {
 	 *
 	 * @param string $message
 	 * @param array $context
-	 * @return void
 	 */
-	public function notice(string $message, array $context = []) {
+	public function notice(string $message, array $context = []): void {
 		$this->log(ILogger::INFO, $message, $context);
 	}
 
@@ -183,9 +158,8 @@ class Log implements ILogger, IDataLogger {
 	 *
 	 * @param string $message
 	 * @param array $context
-	 * @return void
 	 */
-	public function info(string $message, array $context = []) {
+	public function info(string $message, array $context = []): void {
 		$this->log(ILogger::INFO, $message, $context);
 	}
 
@@ -194,9 +168,8 @@ class Log implements ILogger, IDataLogger {
 	 *
 	 * @param string $message
 	 * @param array $context
-	 * @return void
 	 */
-	public function debug(string $message, array $context = []) {
+	public function debug(string $message, array $context = []): void {
 		$this->log(ILogger::DEBUG, $message, $context);
 	}
 
@@ -207,19 +180,21 @@ class Log implements ILogger, IDataLogger {
 	 * @param int $level
 	 * @param string $message
 	 * @param array $context
-	 * @return void
 	 */
-	public function log(int $level, string $message, array $context = []) {
+	public function log(int $level, string $message, array $context = []): void {
 		$minLevel = $this->getLogLevel($context);
+		if ($level < $minLevel
+			&& (($this->crashReporters?->hasReporters() ?? false) === false)
+			&& (($this->eventDispatcher?->hasListeners(BeforeMessageLoggedEvent::class) ?? false) === false)) {
+			return; // no crash reporter, no listeners, we can stop for lower log level
+		}
 
 		array_walk($context, [$this->normalizer, 'format']);
 
 		$app = $context['app'] ?? 'no app in context';
 		$entry = $this->interpolateMessage($context, $message);
 
-		if ($this->eventDispatcher) {
-			$this->eventDispatcher->dispatchTyped(new BeforeMessageLoggedEvent($app, $level, $entry));
-		}
+		$this->eventDispatcher?->dispatchTyped(new BeforeMessageLoggedEvent($app, $level, $entry));
 
 		$hasBacktrace = isset($entry['exception']);
 		$logBacktrace = $this->config->getValue('log.backtrace', false);
@@ -241,16 +216,19 @@ class Log implements ILogger, IDataLogger {
 					$this->crashReporters->delegateMessage($entry['message'], $messageContext);
 				}
 			} else {
-				if ($this->crashReporters !== null) {
-					$this->crashReporters->delegateBreadcrumb($entry['message'], 'log', $context);
-				}
+				$this->crashReporters?->delegateBreadcrumb($entry['message'], 'log', $context);
 			}
 		} catch (Throwable $e) {
 			// make sure we dont hard crash if logging fails
 		}
 	}
 
-	public function getLogLevel($context) {
+	public function getLogLevel($context): int {
+		if ($this->nestingLevel > 1) {
+			return ILogger::WARN;
+		}
+
+		$this->nestingLevel++;
 		$logCondition = $this->config->getValue('log.condition', []);
 
 		/**
@@ -296,24 +274,31 @@ class Log implements ILogger, IDataLogger {
 
 		// if log condition is satisfied change the required log level to DEBUG
 		if ($this->logConditionSatisfied) {
+			$this->nestingLevel--;
 			return ILogger::DEBUG;
 		}
 
 		if (isset($context['app'])) {
-			$app = $context['app'];
-
 			/**
 			 * check log condition based on the context of each log message
 			 * once this is met -> change the required log level to debug
 			 */
-			if (!empty($logCondition)
-				&& isset($logCondition['apps'])
-				&& in_array($app, $logCondition['apps'], true)) {
+			if (in_array($context['app'], $logCondition['apps'] ?? [], true)) {
+				$this->nestingLevel--;
 				return ILogger::DEBUG;
 			}
 		}
 
-		return min($this->config->getValue('loglevel', ILogger::WARN), ILogger::FATAL);
+		$configLogLevel = $this->config->getValue('loglevel', ILogger::WARN);
+		if (is_numeric($configLogLevel)) {
+			$this->nestingLevel--;
+			return min((int)$configLogLevel, ILogger::FATAL);
+		}
+
+		// Invalid configuration, warn the user and fall back to default level of WARN
+		error_log('Nextcloud configuration: "loglevel" is not a valid integer');
+		$this->nestingLevel--;
+		return ILogger::WARN;
 	}
 
 	/**
@@ -324,13 +309,15 @@ class Log implements ILogger, IDataLogger {
 	 * @return void
 	 * @since 8.2.0
 	 */
-	public function logException(Throwable $exception, array $context = []) {
+	public function logException(Throwable $exception, array $context = []): void {
 		$app = $context['app'] ?? 'no app in context';
 		$level = $context['level'] ?? ILogger::ERROR;
 
 		$minLevel = $this->getLogLevel($context);
-		if ($level < $minLevel && ($this->crashReporters === null || !$this->crashReporters->hasReporters())) {
-			return;
+		if ($level < $minLevel
+			&& (($this->crashReporters?->hasReporters() ?? false) === false)
+			&& (($this->eventDispatcher?->hasListeners(BeforeMessageLoggedEvent::class) ?? false) === false)) {
+			return; // no crash reporter, no listeners, we can stop for lower log level
 		}
 
 		// if an error is raised before the autoloader is properly setup, we can't serialize exceptions
@@ -346,12 +333,9 @@ class Log implements ILogger, IDataLogger {
 		$data = array_merge($serializer->serializeException($exception), $data);
 		$data = $this->interpolateMessage($data, isset($context['message']) && $context['message'] !== '' ? $context['message'] : ('Exception thrown: ' . get_class($exception)), 'CustomMessage');
 
-
 		array_walk($context, [$this->normalizer, 'format']);
 
-		if ($this->eventDispatcher) {
-			$this->eventDispatcher->dispatchTyped(new BeforeMessageLoggedEvent($app, $level, $data));
-		}
+		$this->eventDispatcher?->dispatchTyped(new BeforeMessageLoggedEvent($app, $level, $data));
 
 		try {
 			if ($level >= $minLevel) {
@@ -399,7 +383,7 @@ class Log implements ILogger, IDataLogger {
 	 * @param string|array $entry
 	 * @param int $level
 	 */
-	protected function writeLog(string $app, $entry, int $level) {
+	protected function writeLog(string $app, $entry, int $level): void {
 		$this->logger->write($app, $entry, $level);
 	}
 
